@@ -6,11 +6,14 @@
 #   on_help(self)
 #   on_whisper(self,text)
 #
+
+
 import string
 import time
 import orpg.tools.orpg_update
 import orpg.orpg_version
 import orpg.orpg_windows
+import orpg.plugins#mDuo13 added
 import traceback
 
 ##--------------------------------------------------------------
@@ -158,6 +161,14 @@ class chat_commands:
         elif cmd == "/w" or cmd == "/whisper":
             self.on_whisper(cmdlist[1])
 
+        #Group Whisper command
+        elif cmd == "/gw":
+            self.on_groupwhisper(cmdlist[1])
+
+        #GM Whisper command
+        elif cmd == "/gmw" or cmd == "/gm":
+            self.on_gmwhisper(cmdlist[1])
+
         # emote for changing name
         elif cmd == "/name" or cmd == "/nick":
             try:
@@ -169,7 +180,7 @@ class chat_commands:
             local_time = time.localtime()
             gmt_time = time.gmtime()
             format_string = "%A %b %d, %Y  %I:%M:%S%p"
-	    self.chat.InfoPost("<br>Local: " + time.strftime(format_string)+\
+            self.chat.InfoPost("<br>Local: " + time.strftime(format_string)+\
                                "<br>GMT: "+time.strftime(format_string,gmt_time))
         elif cmd == "/status":
             try:
@@ -202,6 +213,12 @@ class chat_commands:
                 self.on_moderate(cmdlist[1])
             else:
                 self.on_moderate("")
+        elif cmd == "/tab":
+            if (len(cmdlist)>1):
+                self.invoke_tab(cmdlist[1])
+            else:
+                self.chat.InfoPost(" ** Invalid ID to Spawn Whisper Tab")
+
         # ping command altered by Snowdog 8/03
         # now sends time data to be returned by server
         elif cmd == "/ping":
@@ -225,7 +242,21 @@ class chat_commands:
                     return
             except:
                 pass
-            self.chat.InfoPost(" ** Sorry, don't understand what a " + cmdlist[0] + " is...")
+            #following added by mDuo13. (Plugin code)
+            a=0
+            #plugins
+            for plugin_fname in orpg.plugins.frame.enabled_plugins.keys():
+                plugin = orpg.plugins.frame.enabled_plugins[plugin_fname]
+                try:
+                    a+=plugin.docmd(self,text,cmdlist)
+                except Exception, e:
+                    if str(e) != "'module' object has no attribute 'docmd'":
+                        #print e
+                        traceback.print_exc()
+            if a==0:
+                #end mDuo13 added code
+                #following line tabbed in by mDuo13
+                self.chat.InfoPost(" ** Sorry, don't understand what a " + cmdlist[0] + " is...")
 
     def on_log(self,cmdlist):
         logfile = self.settings.get_setting( 'GameLogPrefix' )
@@ -261,7 +292,6 @@ class chat_commands:
         if int(str(cmd))>0:
             self.settings.set_setting('buffersize',cmd)
             self.chat.SystemPost("Maximum number of lines in chat now set to "+cmd)
-#            self.chat.buftxt=cmd
             self.chat.on_buffer_size(cmd)
         else:
             self.chat.SystemPost("Maximum lines in chat: "+self.settings.get_setting("buffersize"))
@@ -309,13 +339,13 @@ class chat_commands:
         keys = self.settings.get_setting_keys()
         if len(cmdlist) == 1:
             line = "<table border='2'>"
-	    for m in range(len(keys)):
+            for m in range(len(keys)):
                 line += "<tr><td>" + keys[m] + "</td><td> " + self.settings.get_setting(keys[m]) + "</td></tr>"
             line += "</table>"
             self.chat.InfoPost(line)
         else:
             split_name_from_data = cmdlist[1].find("=")
-	    if split_name_from_data == -1:
+            if split_name_from_data == -1:
                 for m in keys:
                     if m == cmdlist[1]:
                         return_string = "<table border='2'><tr><td>" + cmdlist[1] + "</td><td>"\
@@ -323,10 +353,10 @@ class chat_commands:
                         self.chat.InfoPost(return_string)
             else:
                 name=cmdlist[1][:split_name_from_data].strip()
-		for m in keys:
+                for m in keys:
                     if m == name:
                         setting=cmdlist[1][split_name_from_data+1:].strip()
-		        self.settings.set_setting(name,setting)
+                        self.settings.set_setting(name,setting)
                         return_string = name + " changed to " + setting
                         self.chat.InfoPost(return_string)
                         self.session.set_name(self.settings.get_setting("player"))
@@ -386,7 +416,7 @@ class chat_commands:
                " - Purge history older than your buffersize."
         self.chat.Post(text)
         text = self.colorize( self.chat.infocolor, "/role [player_id = GM | Player | Lurker]") + \
-	        " - Get player roles from ther server, or change the role of a player."
+                " - Get player roles from ther server, or change the role of a player."
         self.chat.Post(text)
         text = self.colorize( self.chat.infocolor, "/set [setting[=value]]") + \
                 " - Displays one or all settings, or sets a setting."
@@ -406,6 +436,12 @@ class chat_commands:
         text =  self.colorize(self.chat.infocolor, "/w player_id_number, ... = message") +\
                 " - Whisper to player(s). Can contain multiple IDs."
         self.chat.Post(text)
+        text =  self.colorize(self.chat.infocolor, "/gw [group_name]=message") +\
+                " - Type /gw help for more information"
+        self.chat.Post(text)
+        text =  self.colorize(self.chat.infocolor, "/gm  message") +\
+                " - Whispers to all GMs in the room"
+        self.chat.Post(text)
 
         # This subroutine will either show the list of currently ignored users
         # !self : instance of self
@@ -438,13 +474,6 @@ class chat_commands:
 
     def on_role(self,text):
         if text == "":
-            self.session.display_roles()
-#            players = self.session.get_players()
-#            for m in players:
-#                try:
-#                    self.chat.InfoPost(m[0] +" is now a " + m[7])
-#                except Exception, e:
-#                    print "exception in on_role",e
             return
         delim = text.find("=")
         if delim < 0:
@@ -468,8 +497,6 @@ class chat_commands:
                         self.session.set_role(m.strip(),role,role_pwd)
             except:
                 traceback.print_exc()
-            #role_pwd_dialog.Destroy()
-#        return
 
         # This subroutine implements the whisper functionality that enables a user
         # to whisper to another user.
@@ -493,11 +520,78 @@ class chat_commands:
         self.previous_whisper = player_ids
         mesg = string.strip(text[delim+1:])
         self.chat.whisper_to_players(mesg,player_ids)
-            #if self.session.is_valid_id(id):
-            #    self.session.send("/w " + mesg, id)
-            #else:
-            #    self.chat.InfoPost(id + " Unknown!")
-        #self.chat.InfoPost("<i>whispering to %s</i> %s" % (string.join(player_ids,", "), mesg))
+
+#---------------------------------------------------------
+# [START] Digitalxero Multi Whisper Group 1/1/05
+#---------------------------------------------------------
+    def on_groupwhisper(self, txt):
+        commands = txt.split(" ")
+        delim = txt.find("=")
+
+        if delim > 0:
+            group_ids = string.split(txt[:delim], ",")
+        elif commands[0] == "add":
+            if not orpg.player_list.WG_LIST.has_key(commands[2]):
+                orpg.player_list.WG_LIST[commands[2]] = {}
+            orpg.player_list.WG_LIST[commands[2]][int(commands[1])] = int(commands[1])
+            return
+        elif commands[0] == "remove" or commands[0] == "delete":
+            del orpg.player_list.WG_LIST[commands[2]][int(commands[1])]
+            if len(orpg.player_list.WG_LIST[commands[2]]) == 0:
+                del orpg.player_list.WG_LIST[commands[2]]
+            return
+        elif commands[0] == "create" or commands[0] == "new_group":
+            if not orpg.player_list.WG_LIST.has_key(commands[1]):
+                orpg.player_list.WG_LIST[commands[1]] = {}
+            return
+        elif commands[0] == "list":
+            for n in orpg.player_list.WG_LIST[commands[1]]:
+                player = self.session.get_player_info(str(n))
+                self.chat.InfoPost(str(player[0]))
+            return
+        elif commands[0] == "clear":
+            orpg.player_list.WG_LIST[commands[1]].clear()
+        elif commands[0] == "clearall":
+            orpg.player_list.WG_LIST.clear()
+            return
+        else:
+            self.chat.InfoPost("/gw add [player_id] [group_name] - Adds [player_id] to [group_name]")
+            self.chat.InfoPost("/gw remove [player_id] [group_name] - Removes [player_id] from [group_name]")
+            self.chat.InfoPost("/gw [group_name]=[message] - Sends [message] to [group_name]")
+            self.chat.InfoPost("/gw create [group_name] - Creates a whisper group called [group_name]")
+            self.chat.InfoPost("/gw list [group_name] - Lists all players in [group_name]")
+            self.chat.InfoPost("/gw clear [group_name] - Removes all players from [group_name]")
+            self.chat.InfoPost("/gw clearall - Removes all existing whisper groups")
+            return
+
+        msg = string.strip(txt[delim+1:])
+        for gid in group_ids:
+            idList = ""
+            for n in orpg.player_list.WG_LIST[gid]:
+                if idList == "":
+                    idList = str(n)
+                else:
+                    idList = str(n) + ", " + idList
+            self.on_whisper(idList + "=" + self.settings.get_setting("gwtext") + msg)
+
+#---------------------------------------------------------
+# [END] Digitalxero Multi Whisper Group 1/1/05
+#---------------------------------------------------------
+
+    def on_gmwhisper(self, txt):
+        if txt == "":
+            self.chat.InfoPost("**Incorrect syntax for GM Whisper.")
+        else:
+            the_gms = self.chat.get_gms()
+            if len(the_gms):
+                gmstring = ""
+                for each_gm in the_gms:
+                    if gmstring != "":
+                        gmstring += ","
+                    gmstring += each_gm
+                self.on_whisper(gmstring+"="+txt)
+            else:
+                self.chat.InfoPost("**No GMs to Whisper to.")
 
     def on_moderate(self,text):
         if text<>"":
@@ -546,17 +640,18 @@ class chat_commands:
         url = self.settings.get_setting( "PackagesBaseURL" )
         Disableupdate = int(self.settings.get_setting("Disableupdate" ))
         updater = orpg.tools.orpg_update.orpg_update(url,self.chat.InfoPost)
-        self.chat.InfoPost("You are running " + orpg.orpg_version.VERSION)
+        self.chat.InfoPost("You are running " + orpg.orpg_version.VERSION + " (build "+orpg.orpg_version.BUILD+")")
         p = updater.get_package()
-        self.chat.InfoPost("The latest version is " + p.getAttribute("version"))
-        is_up2date = updater.is_up2date(orpg.orpg_version.VERSION)
+        self.chat.InfoPost("The latest version is " + p.getAttribute("version") + " (build "+p.getAttribute("build")+")")
+        is_up2date = updater.is_up2date(orpg.orpg_version.VERSION, orpg.orpg_version.BUILD)
         if is_up2date:
-            self.chat.SystemPost("Your code up to date!")
+            self.chat.InfoPost("OpenRPG does not require updating.")
         else:
             self.chat.SystemPost("Your code is out of date!")
+            self.chat.SystemPost("Type \"/update get\" to update to the latest version.")
 
         if cmd=="get" and is_up2date:
-            self.chat.InfoPost("Update canceled")
+            self.chat.InfoPost("OpenRPG does not require updating.")
         elif cmd=="get" and not is_up2date:
             if not Disableupdate:
                 dlg = orpg.orpg_windows.do_progress_dlg(self.chat,"OpenRPG Updater","Please wait while OpenRPG upates...",3)
@@ -567,8 +662,7 @@ class chat_commands:
                 self.chat.SystemPost("Please restart OpenRPG!")
                 dlg.Update(2,"Done.")
                 dlg.Destroy()
-        else:
-            self.chat.InfoPost("Type \"/update get\" to update to the latest version.")
+
 
     def on_description(self, text):
         if len(text) <= 0:
@@ -581,7 +675,29 @@ class chat_commands:
         self.chat.Post(mesg)
         self.chat.send_chat_message(mesg)
 
+    def invoke_tab(self, text):
+        ######START mDuo13's Tab Initiator########
+        playerid = text.strip()
+        tabbed_whispers_p = self.settings.get_setting("tabbedwhispers")
+        panelexists = 0
+        if (tabbed_whispers_p == "1") and self.session.is_valid_id(playerid):
+            # Check to see if parent notebook already has a private tab for player
+            for panel in self.chat.parent.panel_list:
+                if (panel.sendtarget == playerid):
+                    self.chat.InfoPost("Cannot invoke tab: Tab already exists.")
+                    return
+            displaypanel = self.chat.parent.create_private_tab(playerid)
 
+            cidx = self.chat.parent.GetSelection()
+            nidx = self.chat.parent.get_tab_index(displaypanel)
+            self.chat.parent.SetSelection(nidx)
+            self.chat.parent.SetSelection(cidx)
+            self.chat.parent.SetPageImage(nidx, self.chat.parent.chatAttentionIdx)
+            return
+        else:
+            self.chat.Post("Cannot invoke tab: Tabbed whispering is disabled. or Invalid player ID")
+            return
+        #######END mDuo13's Tab Initiator#########
 
     def on_remote_admin(self, cmdlist):
         #handles remote administration commands
