@@ -1,6 +1,6 @@
 # Copyright (C) 2000-2001 The OpenRPG Project
 #
-#	openrpg-dev@lists.sourceforge.net
+#        openrpg-dev@lists.sourceforge.net
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,12 +21,12 @@
 # Author: Chris Davis
 # Maintainer:
 # Version:
-#   $Id: gametree.py,v 1.33 2003/11/21 08:52:30 digitalxero Exp $
+#   $Id: gametree.py,v 1.40 2005/06/05 20:12:33 digitalxero Exp $
 #
 # Description: The file contains code fore the game tree shell
 #
 
-__version__ = "$Id: gametree.py,v 1.33 2003/11/21 08:52:30 digitalxero Exp $"
+__version__ = "$Id: gametree.py,v 1.40 2005/06/05 20:12:33 digitalxero Exp $"
 
 
 
@@ -97,7 +97,7 @@ class game_tree(wxTreeCtrl):
         wxTreeCtrl.__init__(self,parent,id,  wxDefaultPosition, wxDefaultSize,style = wxTR_EDIT_LABELS | wxTR_HAS_BUTTONS)
 
         self.myopenrpg = openrpg
-        
+
         self.build_img_list()
         self.build_std_menu()
         self.nodehandlers = {}
@@ -194,35 +194,83 @@ class game_tree(wxTreeCtrl):
 
         evt.Skip()
 
+    ## locate_valid_tree
+    ## GUI based dialogs to locate/fix missing treefile issues --Snowdog 3/05
+    def locate_valid_tree(self,error,msg,dir,filename):
+        """prompts the user to locate a new tree file or create a new one"""
+
+        response = wxMessageBox(msg,error,wxYES|wxNO|wxICON_ERROR)
+        if response == wxYES:
+            file = None
+            filetypes = "Gametree (*.xml)|*.xml|All files (*.*)|*.*"
+            dlg = wxFileDialog(self, "Locate Gametree file", dir, filename, filetypes,wxOPEN | wxCHANGE_DIR)
+            if dlg.ShowModal() == wxID_OK: file = dlg.GetPath()
+            dlg.Destroy()
+            if not file: self.load_tree(error=1)
+            else: self.load_tree(file)
+            return
+        else:
+            orpg.tools.config_files.validate_config_file("tree.xml","default_tree.xml")
+            self.load_tree(error=1)
+            return
+
+
+
 
     def load_tree(self,filename=orpg.dirpath.dir_struct["user"]+'tree.xml',error=0):
         #self.filename = filename
         s = self.myopenrpg.get_component('settings')
         s.set_setting("gametree",filename)
-        tmp = open(filename,"r")
+        tmp = None
         xml_dom = None
-        xml_doc = parseXml(tmp.read())
-        if xml_doc == None:
-            pass
-        else:
-            xml_dom = xml_doc._get_documentElement()
-        tmp.close()
-        if not xml_dom:
-            wxMessageBox("Corrupt Tree!\nYour game tree is being regenerated. To\nsalvage a recent version of your gametree\nexit OpenRPG and copy the lastgood.xml\nfile in your myfiles directory\nto "+filename+ "\nin your myfiles directory.\nlastgood.xml WILL BE OVERWRITTEN NEXT TIME YOU RUN OPENRPG.")
+        xml_doc = None
+        try:
+            print "Reading Gametree file: " + filename +"...",
+            tmp = open(filename,"r")
+            xml_doc = parseXml(tmp.read())
+            if xml_doc == None: pass
+            else: xml_dom = xml_doc._get_documentElement()
+            tmp.close()
+            print "done."
 
+        except IOError:
+            emsg = "Gametree Missing!\n"+filename+" cannot be found.\n\n"\
+                   "Would you like to locate it?\n"\
+                   "(Selecting 'No' will cause a new default gametree to be generated)"
+            fn = filename[ ((filename.rfind(os.sep))+len(os.sep)):]
+            self.locate_valid_tree("Gametree Error", emsg, orpg.dirpath.dir_struct["user"], fn)
+            return
+
+        if not xml_dom:
             os.rename(filename,filename+".corrupt")
-            orpg.tools.config_files.validate_config_file("tree.xml","default_tree.xml")
-            self.load_tree(error=1)
+            fn = filename[ ((filename.rfind(os.sep))+len(os.sep)):]
+            emsg = "Your gametree is being regenerated.\n\n"\
+                   "To salvage a recent version of your gametree\n"\
+                   "exit OpenRPG and copy the lastgood.xml file in\n"\
+                   "your myfiles directory to "+fn+ "\n"\
+                   "in your myfiles directory.\n\n"\
+                   "lastgood.xml WILL BE OVERWRITTEN NEXT TIME YOU RUN OPENRPG.\n\n"\
+                   "Would you like to select a different gametree file to use?\n"\
+                   "(Selecting 'No' will cause a new default gametree to be generated)"
+            self.locate_valid_tree("Corrupt Gametree!",emsg,orpg.dirpath.dir_struct["user"], fn)
             return
+
+
         if xml_dom._get_tagName() != "gametree":
+            fn = filename[ ((filename.rfind(os.sep))+len(os.sep)):]
+            emsg = fn+" does not appear to be a valid gametree file.\n\n"\
+                   "Would you like to select a different gametree file to use?\n"\
+                   "(Selecting 'No' will cause a new default gametree to be generated)"
+            self.locate_valid_tree("Invalid Gametree!",emsg,orpg.dirpath.dir_struct["user"], fn)
             return
+
+
         # get gametree version - we could write conversion code here!
-	
+
         self.master_dom = xml_dom
-	
+
         try:
             version = self.master_dom.getAttribute("version")
-            print "Loaded " + filename + " gametree version - " + version
 
             # see if we should load the gametree
             s = self.myopenrpg.get_component('settings')
@@ -234,10 +282,14 @@ class game_tree(wxTreeCtrl):
                 s.set_setting("LoadGameTreeFeatures","0")
 
             ## load tree
+
             self.CollapseAndReset(self.root)
             children = self.master_dom._get_childNodes()
+            print "Parsing Gametree Nodes ",
             for c in children:
+                print '.',
                 self.load_xml(c,self.root)
+            print "done"
             self.Expand(self.root)
             self.SetPyData(self.root,self.master_dom)
             if error != 1:
@@ -246,7 +298,7 @@ class game_tree(wxTreeCtrl):
                 outfile.write(infile.read())
             else:
                 print "Not overwriting lastgood.xml file."
-	     
+
         except Exception, e:
             print e
             wxMessageBox("Corrupt Tree!\nYour game tree is being regenerated. To\nsalvage a recent version of your gametree\nexit OpenRPG and copy the lastgood.xml\nfile in your myfiles directory\nto "+filename+ "\nin your myfiles directory.\nlastgood.xml WILL BE OVERWRITTEN NEXT TIME YOU RUN OPENRPG.")
@@ -254,6 +306,7 @@ class game_tree(wxTreeCtrl):
             orpg.tools.config_files.validate_config_file("tree.xml","default_tree.xml")
             self.load_tree(error=1)
 
+
     def build_std_menu(self,obj=None):
         # build useful menu
         useful_menu = wxMenu()
@@ -266,7 +319,7 @@ class game_tree(wxTreeCtrl):
         self.std_menu.Append(STD_MENU_USE,"&Use")
         self.std_menu.Append(STD_MENU_DESIGN,"&Design")
         self.std_menu.Append(STD_MENU_PP,"&Pretty Print")
-        self.std_menu.AppendSeparator()        
+        self.std_menu.AppendSeparator()
         self.std_menu.Append(STD_MENU_SEND,"Send To Player")
         self.std_menu.Append(STD_MENU_MAP,"Send To Map")
         self.std_menu.Append(STD_MENU_CHAT,"Send To Chat")
@@ -294,7 +347,7 @@ class game_tree(wxTreeCtrl):
         EVT_MENU(self, STD_MENU_MAP, self.on_send_to_map)
         EVT_MENU(self, STD_MENU_DESIGN, self.on_node_design)
         EVT_MENU(self, STD_MENU_USE, self.on_node_use)
-        EVT_MENU(self, STD_MENU_PP, self.on_node_pp)        
+        EVT_MENU(self, STD_MENU_PP, self.on_node_pp)
         EVT_MENU(self, STD_MENU_SAVE, self.on_save)
         EVT_MENU(self, STD_MENU_ICON, self.on_icon)
         EVT_MENU(self, STD_MENU_CLONE, self.on_clone)
@@ -344,7 +397,7 @@ class game_tree(wxTreeCtrl):
             else :
                 ret_string = ret_string + player[0][x]
         return ret_string
-    
+
     def on_receive_data(self,data,player):
         beg = string.find(data,"<tree>")
         end = string.rfind(data,"</tree>")
@@ -369,7 +422,7 @@ class game_tree(wxTreeCtrl):
                 opts.append("("+p[2]+") " + self.strip_html(p))
             else:
                 me = p
-        
+
         if len(opts):
            players.remove(me)
 
@@ -561,7 +614,7 @@ class game_tree(wxTreeCtrl):
         item = self.GetSelection()
         obj = self.GetPyData(item)
         obj.on_html_view(evt)
-        
+
     def on_del(self,evt):
         status_value = "none"
         try:
@@ -634,11 +687,11 @@ class game_tree(wxTreeCtrl):
             for c in children:
                 self.load_xml(c,self.root)
             return
-        
+
         if not xml_dom:
             wxMessageBox("XML Error")
             return
-        
+
         xml_dom = xml_dom._get_firstChild()
         child = self.master_dom._get_firstChild()
         xml_dom = self.master_dom.insertBefore(xml_dom,child)
@@ -819,7 +872,7 @@ class game_tree(wxTreeCtrl):
             evt.Veto()
         else:
             self.was_labeling = 1
-            item = evt.GetItem() 
+            item = evt.GetItem()
             if item == self.GetRootItem():
                 evt.Veto()
 
@@ -845,10 +898,10 @@ class game_tree(wxTreeCtrl):
             return 0
         else:
             return self.is_parent_node(parent_node,compare_node)
-            
-    
 
-CTRL_TREE_FILE	= wxNewId()
+
+
+CTRL_TREE_FILE        = wxNewId()
 CTRL_YES = wxNewId()
 CTRL_NO = wxNewId()
 CTRL_USE = wxNewId()
@@ -893,18 +946,18 @@ class gametree_prop_dlg(wxDialog):
         self.ctrls[CTRL_USE].SetValue(opt=="use")
         self.ctrls[CTRL_CHAT].SetValue(opt=="chat")
         self.ctrls[CTRL_PRINT].SetValue(opt=="print")
-        
-        
+
+
         sizers['save'].Add(self.ctrls[CTRL_YES],0, wxEXPAND)
-        sizers['save'].Add(10,10)
+        sizers['save'].Add(wxSize(10,10))
         sizers['save'].Add(self.ctrls[CTRL_NO],0, wxEXPAND)
 
         sizers['dclick'].Add(self.ctrls[CTRL_USE],0, wxEXPAND)
-        sizers['dclick'].Add(10,10)
+        sizers['dclick'].Add(wxSize(10,10))
         sizers['dclick'].Add(self.ctrls[CTRL_DESIGN],0, wxEXPAND)
-        sizers['dclick'].Add(10,10)
+        sizers['dclick'].Add(wxSize(10,10))
         sizers['dclick'].Add(self.ctrls[CTRL_CHAT],0, wxEXPAND)
-        sizers['dclick'].Add(10,10)
+        sizers['dclick'].Add(wxSize(10,10))
         sizers['dclick'].Add(self.ctrls[CTRL_PRINT],0, wxEXPAND)
 
         box_sizers["save"].set_sizer(sizers["save"])
@@ -915,17 +968,17 @@ class gametree_prop_dlg(wxDialog):
             box.SetSize(wxSize(20,65))
 
         csize = self.GetClientSizeTuple()
-	
+
         # buttons
         sizers['but'].Add(wxButton(self, wxID_OK, "Apply"), 1, wxEXPAND)
-        sizers['but'].Add(10,10)
+        sizers['but'].Add(wxSize(10,10))
         sizers['but'].Add(wxButton(self, wxID_CANCEL, "Cancel"), 1, wxEXPAND)
 
-        
+
         sizers['main'].Add(box_sizers['save'],1, wxEXPAND)
         sizers['main'].Add(box_sizers['file'],1, wxEXPAND)
         sizers['main'].Add(box_sizers['dclick'],1, wxEXPAND)
-        sizers['main'].Add(sizers['but'],0, wxEXPAND|wxALIGN_BOTTOM )        
+        sizers['main'].Add(sizers['but'],0, wxEXPAND|wxALIGN_BOTTOM )
         sizers['main'].SetDimension(10,10,csize[0]-20,csize[1]-20)
         self.SetSizer(sizers['main'])
         EVT_BUTTON(self, wxID_OK, self.on_ok)
@@ -941,6 +994,6 @@ class gametree_prop_dlg(wxDialog):
             self.settings.set_setting("treedclick","print")
         elif self.ctrls[CTRL_CHAT].GetValue():
             self.settings.set_setting("treedclick","chat")
-	self.EndModal(wxID_OK)
+        self.EndModal(wxID_OK)
+
 
-         
