@@ -21,12 +21,12 @@
 # Author: Ted Berg
 # Maintainer:
 # Version:
-#   $Id: minilib.py,v 1.13 2003/01/14 23:11:06 posterboy Exp $
+#   $Id: minilib.py,v 1.14 2004/05/11 03:31:26 markt1964 Exp $
 #
 # Description: nodehandler for a collection of miniatures.
 #
 
-__version__ = "$Id: minilib.py,v 1.13 2003/01/14 23:11:06 posterboy Exp $"
+__version__ = "$Id: minilib.py,v 1.14 2004/05/11 03:31:26 markt1964 Exp $"
 
 """Nodehandler for collections of miniatures.  User can add, delete, edit 
 miniatures as sending them to the map singly or in batches.
@@ -307,7 +307,7 @@ class minilib_use_panel( wxPanel ):
         self.count = wxTextCtrl( self, MINICOUNT_ID, '1' )
 
         box.Add( wxStaticText( self, -1, 'Minis to add' ), 0, wxEXPAND )
-        box.Add( 10, 10 )
+        box.Add(wxSize(10,10))
         box.Add( self.count, 1, wxEXPAND )
         
         self.sizer.Add( self.listbox, 1, wxEXPAND )
@@ -316,7 +316,7 @@ class minilib_use_panel( wxPanel ):
         box = wxBoxSizer( wxHORIZONTAL )
         box.Add( wxButton( self, OK_BUTTON, 'Add' ), 0, wxEXPAND )
         box.Add( wxButton( self, CANCEL_BUTTON, 'Done' ), 0, wxEXPAND )
-        self.sizer.Add( 10, 10 )
+        self.sizer.Add(wxSize(10,10))
         self.sizer.Add( box, 0, wxEXPAND )
         EVT_SIZE( self, self.on_size )
         EVT_BUTTON( self, OK_BUTTON, self.on_ok )
@@ -403,7 +403,7 @@ class minpedit( wxPanel ):
         bbox = wxBoxSizer( wxHORIZONTAL )
         bbox.Add( wxButton( self, ADD_MINI, "New mini" ), 0, wxEXPAND )
         bbox.Add( wxButton( self, DEL_MINI, "Del mini" ), 0, wxEXPAND )
-        bbox.Add( 10, 10 )
+        bbox.Add(wxSize(10,10))
         bbox.Add( wxButton( self, SEND_TO_MAP, "Add 1" ), 0, wxEXPAND )
         bbox.Add( wxButton( self, SEND_GROUP_TO_MAP, "Add Batch" ), 0, 
             wxEXPAND )
