@@ -1,6 +1,6 @@
 # Copyright (C) 2000-2001 The OpenRPG Project
 #
-#	openrpg-dev@lists.sourceforge.net
+#        openrpg-dev@lists.sourceforge.net
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,12 +21,12 @@
 # Author: Chris Davis
 # Maintainer:
 # Version:
-#   $Id: rpg_grid.py,v 1.5 2002/08/21 23:30:00 posterboy Exp $
+#   $Id: rpg_grid.py,v 1.7 2005/06/05 20:12:36 digitalxero Exp $
 #
 # Description: The file contains code for the grid nodehanlers
 #
 
-__version__ = "$Id: rpg_grid.py,v 1.5 2002/08/21 23:30:00 posterboy Exp $"
+__version__ = "$Id: rpg_grid.py,v 1.7 2005/06/05 20:12:36 digitalxero Exp $"
 
 from core import *
 from forms import *
@@ -37,12 +37,12 @@ class rpg_grid_handler(node_handler):
   <grid border='' autosize='1' >
     <row>
       <cell size='?'></cell>
-      <cell></cell>      
+      <cell></cell>
     </row>
     <row>
       <cell></cell>
-      <cell></cell>      
-    </row>    
+      <cell></cell>
+    </row>
   </grid>
   <macros>
     <macro name=''/>
@@ -59,36 +59,36 @@ class rpg_grid_handler(node_handler):
         self.macros = self.master_dom.getElementsByTagName('macros')[0]
         self.frame = openrpg.get_component('frame')
         self.myeditor = None
-        self.refresh_rows()   
-        
+        self.refresh_rows()
+
     def refresh_die_macros(self):
         pass
-    
+
     def refresh_rows(self):
         self.rows = {}
         tree = self.tree
         icons = self.tree.icons
         tree.CollapseAndReset(self.mytree_node)
         node_list = self.master_dom.getElementsByTagName('row')
-        for n in node_list:   
+        for n in node_list:
             cells = n.getElementsByTagName('cell')
             t_node = cells[0]._get_firstChild()
             if t_node == None:
-                name = "Row"          
+                name = "Row"
             else:
                 name = t_node._get_nodeValue()
             if name == "":
                 name = "Row"
-            new_tree_node = tree.AppendItem(self.mytree_node,name,icons['gear'],icons['gear'])        
+            new_tree_node = tree.AppendItem(self.mytree_node,name,icons['gear'],icons['gear'])
             handler = grid_row_handler(n,new_tree_node,self.myopenrpg,self)
             tree.SetPyData(new_tree_node,handler)
-            
-    
-    def tohtml(self):  
+
+
+    def tohtml(self):
         border = self.grid.getAttribute("border")
         name = self.master_dom.getAttribute('name')
         rows = self.grid.getElementsByTagName('row')
-        colspan = str(len(rows[0].getElementsByTagName('cell')))        
+        colspan = str(len(rows[0].getElementsByTagName('cell')))
         html_str = "<table border=\""+border+"\" align=center><tr bgcolor=\""+TH_BG+"\" ><th colspan="+colspan+">"+name+"</th></tr>"
         for r in rows:
             cells = r.getElementsByTagName('cell')
@@ -100,12 +100,12 @@ class rpg_grid_handler(node_handler):
                 if t_node == None:
                     html_str += "<br></td>"
                 else:
-                    html_str += t_node._get_nodeValue() + "</td>"       
+                    html_str += t_node._get_nodeValue() + "</td>"
             html_str += "</tr>"
         html_str += "</table>"
-        return html_str  
-     
-    def get_design_panel(self,parent): 
+        return html_str
+
+    def get_design_panel(self,parent):
         return rpg_grid_edit_panel(parent,self)
 
     def get_use_panel(self,parent):
@@ -113,10 +113,10 @@ class rpg_grid_handler(node_handler):
 
     def get_size_constraint(self):
         return 1
-        
+
     def is_autosized(self):
         return int(self.grid.getAttribute("autosize"))
-        
+
     def set_autosize(self,autosize=1):
         self.grid.setAttribute("autosize",str(autosize))
 
@@ -342,39 +342,39 @@ class rpg_grid(wxGrid):
         self.handler = handler
 
         #  Registers a "custom" cell editor (really the example from Robin Dunn with minor mods
-        self.RegisterDataType(wxGRID_VALUE_STRING,wxGridCellStringRenderer(),MyCellEditor())       	
-               
+        self.RegisterDataType(wxGRID_VALUE_STRING,wxGridCellStringRenderer(),MyCellEditor())
+
         self.rows = handler.grid.getElementsByTagName('row')
         rows = len(self.rows)
         cols = len(self.rows[0].getElementsByTagName('cell'))
         self.CreateGrid(rows,cols)
         self.SetRowLabelSize(0)
-        self.SetColLabelSize(0)        
-        
+        self.SetColLabelSize(0)
+
         if handler.is_autosized():
             EVT_SIZE(self, self.on_size)
         else:
             self.set_col_widths()
-            
+
         for i in range(0,len(self.rows)):
             self.refresh_row(i)
-        
+
         EVT_GRID_CELL_CHANGE(self, self.on_cell_change)
         EVT_GRID_COL_SIZE(self, self.on_col_size)
-        EVT_GRID_CELL_LEFT_DCLICK(self, self.on_leftdclick)        
-        
-        
+        EVT_GRID_CELL_LEFT_DCLICK(self, self.on_leftdclick)
+
+
     def fit_cols(self):
         (w,h) = self.GetClientSizeTuple()
         cols = self.GetNumberCols()
-        col_w = w/(cols)        
+        col_w = w/(cols)
         for i in range(0,cols):
-            self.SetColSize(i,col_w) 
+            self.SetColSize(i,col_w)
         self.Refresh()
 
-    def on_size(self,evt): 
-        self.fit_cols()                        
-        evt.Skip()        
+    def on_size(self,evt):
+        self.fit_cols()
+        evt.Skip()
 
     def on_leftdclick(self,evt):
         if self.CanEnableCellControl():
@@ -417,7 +417,7 @@ class rpg_grid(wxGrid):
                 t_node = minidom.Text("")
                 t_node = cells[i].appendChild(t_node)
             self.SetCellValue(rowi,i,t_node._get_nodeValue())
-        
+
     def add_row(self,evt=None):
         cols = self.GetNumberCols()
         #doc = self.handler.grid.ownerDocument
@@ -471,21 +471,21 @@ class rpg_grid_panel(wxPanel):
     def __init__(self, parent, handler):
         wxPanel.__init__(self, parent, -1)
         self.handler = handler
-        self.grid = rpg_grid(self,handler) 
-        label = handler.master_dom.getAttribute('name')        
+        self.grid = rpg_grid(self,handler)
+        label = handler.master_dom.getAttribute('name')
         self.main_sizer = wxBoxSizer(wxVERTICAL)
         self.main_sizer.Add(wxStaticText(self, -1, label+": "), 0, wxEXPAND)
-        #self.main_sizer.Add(10,10)
+        #self.main_sizer.Add(wxSize(10,10))
         self.main_sizer.Add(self.grid,1,wxEXPAND)
         self.SetSizer(self.main_sizer)
-        EVT_SIZE(self, self.on_size)        
-        
+        EVT_SIZE(self, self.on_size)
+
     def on_size(self,evt):
         s = self.GetClientSizeTuple()
         self.main_sizer.SetDimension(0,0,s[0],s[1])
-        
 
-G_AUTO_SIZE = wxNewId()   
+
+G_AUTO_SIZE = wxNewId()
 G_ADD_ROW = wxNewId()
 G_ADD_COL = wxNewId()
 G_DEL_ROW = wxNewId()
@@ -501,33 +501,33 @@ class rpg_grid_edit_panel(wxPanel):
         radio_b = wxRadioBox(self, GRID_BOR, "Border (HTML)", choices=["no","yes"])
         border = handler.grid.getAttribute("border")
         radio_b.SetSelection(int(border))
-        
+
         self.auto_size = wxCheckBox(self, G_AUTO_SIZE, " Auto Size")
         self.auto_size.SetValue(handler.is_autosized())
 
         sizer = wxBoxSizer(wxHORIZONTAL)
         sizer.Add(wxButton(self, G_ADD_ROW, "Add Row"), 1, wxEXPAND)
-        sizer.Add(10,10)
+        sizer.Add(wxSize(10,10))
         sizer.Add(wxButton(self, G_DEL_ROW, "Remove Row"), 1, wxEXPAND)
-        sizer.Add(10,10)
+        sizer.Add(wxSize(10,10))
         sizer.Add(wxButton(self, G_ADD_COL, "Add Column"), 1, wxEXPAND)
-        sizer.Add(10,10)
+        sizer.Add(wxSize(10,10))
         sizer.Add(wxButton(self, G_DEL_COL, "Remove Column"), 1, wxEXPAND)
 
         self.main_sizer = wxBoxSizer(wxVERTICAL)
         self.main_sizer.Add(wxStaticText(self, -1, "Title:"), 0, wxEXPAND)
         self.main_sizer.Add(self.title, 0, wxEXPAND)
-        #self.main_sizer.Add(10,10)
+        #self.main_sizer.Add(wxSize(10,10))
         self.main_sizer.Add(radio_b, 0, 0)
-        #self.main_sizer.Add(10,10)
+        #self.main_sizer.Add(wxSize(10,10))
         self.main_sizer.Add(self.auto_size, 0, 0)
-        #self.main_sizer.Add(10,10)
+        #self.main_sizer.Add(wxSize(10,10))
         self.main_sizer.Add(self.grid,1,wxEXPAND)
         self.main_sizer.Add(sizer,0,wxEXPAND)
 
         self.outline = wxStaticBox(self,-1,"Grid")
         self.SetSizer(self.main_sizer)
-        
+
         EVT_SIZE(self, self.on_size)
         EVT_TEXT(self, G_TITLE, self.on_text)
         EVT_BUTTON(self, G_ADD_ROW, self.grid.add_row)
@@ -536,10 +536,10 @@ class rpg_grid_edit_panel(wxPanel):
         EVT_BUTTON(self, G_DEL_COL, self.grid.del_col)
         EVT_RADIOBOX(self, GRID_BOR, self.on_radio_box)
         EVT_CHECKBOX(self, G_AUTO_SIZE, self.on_auto_size)
-    
+
     def on_auto_size(self,evt):
         self.handler.set_autosize(evt.Checked())
-    
+
     def on_radio_box(self,evt):
         id = evt.GetId()
         index = evt.GetInt()
