@@ -21,18 +21,18 @@
 # Author: Ted Berg
 # Maintainer:
 # Version:
-#   $Id: voxchat.py,v 1.14 2003/02/11 19:48:55 posterboy Exp $
+#   $Id: voxchat.py,v 1.16 2005/11/15 06:40:18 mduo13 Exp $
 #
 # Description: nodehandler for alias.
 #
 
-__version__ = "$Id: voxchat.py,v 1.14 2003/02/11 19:48:55 posterboy Exp $"
+__version__ = "$Id: voxchat.py,v 1.16 2005/11/15 06:40:18 mduo13 Exp $"
 
 import core
 import orpg.tools.scriptkit
 # import base
 import orpg.tools.predTextCtrl
-from wxPython.misc import wxNewId
+from wxPython.wx import wxNewId
 import orpg.tools.rgbhex
 import orpg.dirpath
 import re
@@ -393,11 +393,11 @@ class voxchat_filter_edit_panel( wxPanel ):
         
         buttonsizer = wxBoxSizer( wxHORIZONTAL )
         buttonsizer.Add( wxButton( self, ADD_RULE, LABEL_ADD_RULE ) )
-        buttonsizer.Add( 2, 2 )
+        buttonsizer.Add(wxSize(2,2))
         buttonsizer.Add( wxButton( self, DEL_RULE, LABEL_DELETE_RULE ) )
-        buttonsizer.Add( 2, 2 )
+        buttonsizer.Add(wxSize(2,2))
         buttonsizer.Add( wxButton( self, MOVE_RULE_UP, LABEL_MOVE_UP ) )
-        buttonsizer.Add( 2, 2 )
+        buttonsizer.Add(wxSize(2,2))
         buttonsizer.Add( wxButton( self, MOVE_RULE_DOWN, LABEL_MOVE_DOWN ) )
 
         sizer.Add( self.grid, 1, wxEXPAND )
@@ -678,15 +678,15 @@ class voxchat_newuse_panel( wxPanel ):
         buttonbarsizer = wxBoxSizer( wxHORIZONTAL )
         buttonbarsizer.Add( createMaskedButton(self, orpg.dirpath.dir_struct["icon"]+'install.gif', TOOLTIP_1, UPDATE_LIST_ACTION, '#c0c0c0' ) )
         buttonbarsizer.Add( createMaskedButton(self, orpg.dirpath.dir_struct["icon"]+'folder.gif', TOOLTIP_8, EXPORT_FILTER_ACTION ) )
-        buttonbarsizer.Add( 2, 2 )
+        buttonbarsizer.Add(wxSize(2,2))
         buttonbarsizer.Add( createMaskedButton(self, orpg.dirpath.dir_struct["icon"]+'player.gif', TOOLTIP_2, ADD_ALIAS ) )
         buttonbarsizer.Add( createMaskedButton(self, orpg.dirpath.dir_struct["icon"]+'noplayer.gif', TOOLTIP_3, DEL_ALIAS ) )
         buttonbarsizer.Add( createMaskedButton(self, orpg.dirpath.dir_struct["icon"]+'questionhead.gif', TOOLTIP_4, EDIT_ALIAS ) )
-        buttonbarsizer.Add( 2, 2 )
+        buttonbarsizer.Add(wxSize(2,2))
         buttonbarsizer.Add( createMaskedButton( self, orpg.dirpath.dir_struct["icon"]+'add_filter.gif', TOOLTIP_5, ADD_FILTER, wxBLUE ) )
         buttonbarsizer.Add( createMaskedButton( self, orpg.dirpath.dir_struct["icon"]+'delete_filter.gif', TOOLTIP_6, DEL_FILTER, wxBLUE) )
         buttonbarsizer.Add( createMaskedButton( self, orpg.dirpath.dir_struct["icon"]+'edit_filter.gif', TOOLTIP_7, EDIT_FILTER, wxRED) )
-        buttonbarsizer.Add( 2, 2 )
+        buttonbarsizer.Add(wxSize(2,2))
         buttonbarsizer.Add( createMaskedButton( self, orpg.dirpath.dir_struct["icon"]+'bold.gif', '', BOLD_TEXT, '#bdbdbd') )
         buttonbarsizer.Add( createMaskedButton( self, orpg.dirpath.dir_struct["icon"]+'italic.gif', '', ITAL_TEXT, '#bdbdbd' ) )
         buttonbarsizer.Add( createMaskedButton( self, orpg.dirpath.dir_struct["icon"]+'underlined.gif', '', UNDR_TEXT, '#bdbdbd' ) )
@@ -700,24 +700,24 @@ class voxchat_newuse_panel( wxPanel ):
         btn = wxButton( self, CHAT_ACTION, LABEL_SAY )
         # btn.SetDefault()
         buttonsizer.Add( btn, 0, wxEXPAND )
-        buttonsizer.Add( 2, 2 )
+        buttonsizer.Add(wxSize(2,2))
         buttonsizer.Add( wxButton( self, EMOTE_ACTION, LABEL_DO ), 0, wxEXPAND )
-        buttonsizer.Add( 2, 2 )
+        buttonsizer.Add(wxSize(2,2))
         buttonsizer.Add( wxButton( self, WHISPER_ACTION, LABEL_WHISPER ), 0, wxEXPAND )
-        buttonsizer.Add( 2, 2 )
+        buttonsizer.Add(wxSize(2,2))
         buttonsizer.Add( wxButton( self, RAW_SEND_ACTION, LABEL_SEND_RAW ), 0, wxEXPAND )
-        buttonsizer.Add( 2, 2 )
+        buttonsizer.Add(wxSize(2,2))
         buttonsizer.Add( wxButton( self, DONE_ACTION, LABEL_DONE ), 0, wxEXPAND )
         
         self.sizer = wxBoxSizer( wxVERTICAL )
         self.sizer.Add( buttonbarsizer, 0, wxEXPAND )
-        self.sizer.Add( 2, 2 )
+        self.sizer.Add(wxSize(2,2))
         self.sizer.Add( self.splitter, 1, wxEXPAND )
-        self.sizer.Add( 2, 2 )
+        self.sizer.Add(wxSize(2,2))
         self.sizer.Add( self.useFilter )
-        self.sizer.Add( 100, 2 )
+        self.sizer.Add(wxSize(100,2))
         self.sizer.Add( self.autoClearText )
-        self.sizer.Add( 2, 2 )
+        self.sizer.Add(wxSize(2,2))
         self.sizer.Add( buttonsizer, 0, wxEXPAND )
         EVT_SIZE( self, self.on_size )
         EVT_BUTTON( self, UPDATE_LIST_ACTION, self.on_update_list_action )
