@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # Copyright (C) 2000-2001 The OpenRPG Project
 #
-#	openrpg-dev@lists.sourceforge.net
+#        openrpg-dev@lists.sourceforge.net
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,14 +22,14 @@
 # Author: Chris Davis
 # Maintainer:
 # Version:
-#   $Id: main.py,v 1.69 2003/11/20 06:41:26 tdb30_ Exp $
+#   $Id: main.py,v 1.80 2005/11/07 03:21:05 mduo13 Exp $
 #
 # Description: This is the main entry point of the oprg application
 #
 
-__version__ = "$Id: main.py,v 1.69 2003/11/20 06:41:26 tdb30_ Exp $"
-
+__version__ = "$Id: main.py,v 1.80 2005/11/07 03:21:05 mduo13 Exp $"
 
+import orpg.plugins#mDuo13 added
 from orpg_version import *
 import orpg.dirpath
 from orpg.orpg_windows import *
@@ -46,6 +46,7 @@ from wxPython.lib.splashscreen import SplashScreen
 from string import *
 import orpg.tools.toolBars
 import orpg.tools.passtool
+import orpg.tools.autoupdate
 import orpg.dieroller.utils
 
 import orpg.networking.mplay_client
@@ -57,6 +58,7 @@ import time
 import thread
 import traceback
 import orpg.tools.orpg_sound
+import sys
 
 # menu ids
 EXIT_TOOL = wxNewId()
@@ -71,6 +73,7 @@ INSTALL_TOOL = wxNewId()
 
 #MENU_FLUSH_CACHE = wxNewId()
 
+PLUGIN_TOOL = wxNewId()#mDuo13 added
 MAP_TOOL = wxNewId()
 #INIT_TOOL = wxNewId()
 CHAT_TOOL = wxNewId()
@@ -87,7 +90,7 @@ PWDMGR_TOOL = wxNewId()
 #help menu imports and ids
 import webbrowser
 ONLINE_USERGUIDE = wxNewId()
-ONLINE_HELP_URL ="http://www.dryth.com/modules.php?name=UserGuide"
+ONLINE_HELP_URL ="http://openrpg.wrathof.com/faq"
 
 
 # windowing options
@@ -253,12 +256,12 @@ class orpgFrame(wxFrame):
             self.SetIcon( icon )
 
         self.settings = orpg.tools.orpg_settings.settings()
-        
+
         # create session
         call_backs = {"on_receive":self.on_receive,
-        	"on_mplay_event":self.on_mplay_event,
-        	"on_group_event":self.on_group_event,
-        	"on_player_event":self.on_player_event,
+                "on_mplay_event":self.on_mplay_event,
+                "on_group_event":self.on_group_event,
+                "on_player_event":self.on_player_event,
                 "on_status_event":self.on_status_event,
                 "on_password_signal":self.on_password_signal,
                 "orpgFrame":self}
@@ -268,17 +271,18 @@ class orpgFrame(wxFrame):
         self.poll_timer.Start(500)
         self.ping_timer = mytimer(self.session.update)
 
+
         # create roller manager
         self.roller_manager = orpg.dieroller.utils.roller_manager(self.settings.get_setting("dieroller"))
 
         #create password manager --SD 8/03
         self.password_manager = orpg.tools.passtool.PassTool()
-    
+
         self.myopenrpg = open_rpg({ "session":self.session,
-        			    'frame':self, 'settings':self.settings,
-        			    'roller_manager':self.roller_manager,
+                                    'frame':self, 'settings':self.settings,
+                                    'roller_manager':self.roller_manager,
                                     'password_manager':self.password_manager})
-        
+
         # build frame windows
         self.build_menu()
         self.build_gui()
@@ -289,6 +293,15 @@ class orpgFrame(wxFrame):
         self.tree.load_tree(self.settings.get_setting("gametree"))
         self.players.size_cols()
 
+        #Plugins Window
+        orpg.plugins.frame = orpg.plugins.PluginFrame( self, -1 )#mDuo13 added
+
+        # check for updates
+        autoupdater = orpg.tools.autoupdate.AutoUpdate()
+        if (autoupdater.check(self, self.settings)):
+            self.closed_confirmed()
+
+
         EVT_CLOSE(self,self.OnCloseWindow)
         #self.set_window_mode(int(s.get_setting("MultipleWindows")))
 
@@ -300,9 +313,9 @@ class orpgFrame(wxFrame):
                 self.password_manager.Enable()
             else:
                 self.password_manager.Disable()
-        
 
-        
+
+
     def on_password_signal(self,signal,type,id,data):
         try:
             print ("DEBUG: password response= "+str(signal)+" (T:"+str(type)+"  #"+str(id)+")" )
@@ -321,8 +334,8 @@ class orpgFrame(wxFrame):
                     pass
         except:
             traceback.print_exc()
-            
-            
+
+
     def reset_windows(self, evt=None):
         settings = self.myopenrpg.get_component('settings')
         layouts = self.frame_layouts
@@ -409,6 +422,16 @@ class orpgFrame(wxFrame):
         posx = int(xml_dom.getAttribute("posx"))
         posy = int(xml_dom.getAttribute("posy"))
 
+        ## On Apple OSX the apple menu bar is not figured into the available screen space
+        ## This fix adjusts the window position automatically so the top of
+        ## the openrpg window doesn't appear behind the apple menu
+        ## current as of OSX 10.3.8 --Snowdog 2-22-05
+        if sys.platform == 'darwin':
+            if posy < 45: posy = 45
+
+
+
+
         if posy > screen_h:
             posy = 0
         if posx > screen_w:
@@ -421,7 +444,7 @@ class orpgFrame(wxFrame):
         #    s.SetSashPosition(300)
 
     def post_show_init(self):
-        # Some actions need to be done after the main window is created and shown.  
+        # Some actions need to be done after the main window is created and shown.
         # You can place that code here
         for d in self.dlgs:
             d.Show(1)
@@ -451,7 +474,7 @@ class orpgFrame(wxFrame):
             name = c.getAttribute("name")
             temp_wnd.AddPage(wnd,name)
         return temp_wnd
-        
+
     def do_dlg_window(self,xml_dom,parent_wnd):
         children = xml_dom._get_childNodes()
         name = children[0].getAttribute("name")
@@ -468,7 +491,7 @@ class orpgFrame(wxFrame):
         name = xml_dom._get_nodeName()
         #container = 0
         if name=="tab":
-            temp_wnd = self.do_tab_window(xml_dom,parent_wnd)            
+            temp_wnd = self.do_tab_window(xml_dom,parent_wnd)
         elif name=="splitter":
             temp_wnd = self.do_splitter_window(xml_dom,parent_wnd)
             self.splitters.append(temp_wnd)
@@ -482,7 +505,7 @@ class orpgFrame(wxFrame):
             temp_wnd = orpg.gametree.gametree.game_tree(parent_wnd,-1,self.myopenrpg)
             self.tree = temp_wnd
         elif name=="chat":
-            if self.settings.get_setting('tabbedwhispers') == "1":             
+            if self.settings.get_setting('tabbedwhispers') == "1":
                 temp_wnd = orpg.chat.chatwnd.chat_notebook(parent_wnd, -1,self.myopenrpg)
                 self.chat = temp_wnd.MainChatPanel
             else:
@@ -528,16 +551,13 @@ class orpgFrame(wxFrame):
         #self.mainmenu.Append( menu, "&Windows" )
 
         menu = wxMenu()
+        menu.Append( PLUGIN_TOOL, "&Plugins" )#mDuo13 added
         self.toolmenu = menu
         menu.AppendSeparator()
         #menu.Append( INIT_TOOL, "&Initiative" )
-	try:
-            menu.Append( PWDMGR_TOOL, "Password Manager", helpString = "Enable/disable the Password Manager", kind = wxITEM_CHECK )
-            EVT_MENU(self, PWDMGR_TOOL, self.toggle_password_manager)
-        except:
-            dlg = wxMessageDialog(self,"Password Manager tool dissabled.\n\nPlease Upgrade your wxPython")
-            if dlg.ShowModal() == wxOK:
-                pass
+        menu.AppendCheckItem( PWDMGR_TOOL, "Password Manager", "Enable/disable the Password Manager")
+        EVT_MENU(self, PWDMGR_TOOL, self.toggle_password_manager)
+        
         menu.AppendSeparator()
         menu.Append( DICEBAR_TOOL, "&Dice Tool Bar\tCtrl-D" )
         menu.Append( MAPBAR_TOOL, "&Map Tool Bar" )
@@ -545,6 +565,7 @@ class orpgFrame(wxFrame):
         menu.Enable( MAPBAR_TOOL, false )
         self.mainmenu.Append( menu, "&Tools" )
 
+        EVT_MENU(self, PLUGIN_TOOL, self.on_window)#mDuo13 added
         EVT_MENU(self, CHAT_TOOL, self.on_window)
         EVT_MENU(self, MAP_TOOL, self.on_window)
         EVT_MENU(self, PLAYER_TOOL, self.on_window)
@@ -556,7 +577,7 @@ class orpgFrame(wxFrame):
         EVT_MENU(self, D_LAYOUT, self.reset_windows)
 #        EVT_MENU(self, AUTO_SPLITTER_TOGGLE, self.toggle_autosplitters)
         EVT_MENU(self, ABOUT_TOOL, self.OnAbout)
-        
+
         #--------------------------------------------------------
         # help menu by Snowdog 5/03
         #--------------------------------------------------------
@@ -570,14 +591,14 @@ class orpgFrame(wxFrame):
 
 
 
-    
+
 
     #--------------------------------------------------------
     # ONLINE HELP GUIDE MENU LINK by Snowdog 5/03
     #--------------------------------------------------------
-    def on_user_guide_online(self,event):                
-        wb = webbrowser.get() 
-        wb.open(ONLINE_HELP_URL) 
+    def on_user_guide_online(self,event):
+        wb = webbrowser.get()
+        wb.open(ONLINE_HELP_URL)
 
 
 
@@ -608,6 +629,11 @@ class orpgFrame(wxFrame):
         elif id == PLAYER_TOOL:
             self.player_frame.Show( true )
             self.player_frame.Raise()
+        #mDuo13 added lines below
+        elif id == PLUGIN_TOOL:
+            orpg.plugins.frame.Show(true)
+            orpg.plugins.frame.Raise()
+        #end mDuo13 added lines
         elif id == MAPBAR_TOOL:
             self.mapToolBar.Show( true )
             self.mapToolBar.Raise()
@@ -631,7 +657,7 @@ class orpgFrame(wxFrame):
         if s.get_setting("Heartbeat") == "1":
             self.ping_timer.Start(1000*60*PING_INTERVAL)
             print "starting heartbeat..."
-    
+
 
     def launch_gameserver(self,evt):
 ##        execommand = sys.executable + " start_server_gui.py "
@@ -648,7 +674,7 @@ class orpgFrame(wxFrame):
         else:
             arg = orpg.dirpath.dir_struct["home"] + 'start_server_gui.py'
             args = (arg,arg)
-  
+
         os.spawnv( os.P_NOWAIT, sys.executable, args )
         start_dialog.Update( 1 )
 
@@ -743,7 +769,7 @@ class orpgFrame(wxFrame):
             display_name = "Server Administrator"
 
         if data[:5] == "<tree":
-            self.tree.on_receive_data(data,player)            
+            self.tree.on_receive_data(data,player)
             self.chat.InfoPost(display_name + " has sent you a tree node...")
             #self.tree.OnNewData(data)
 
@@ -843,14 +869,38 @@ class orpgFrame(wxFrame):
 
     def closed_confirmed(self):
         self.save_layout()
-        s = self.myopenrpg.get_component('settings')
-        s.save()
-        self.map.pre_exit_cleanup()
-        save_tree = string.upper(s.get_setting("SaveGameTreeOnExit"))
-        if  (save_tree <> "0") and (save_tree <> "FALSE") and (save_tree <> "NO"):
-            self.tree.save_tree(s.get_setting("gametree"))
+        try:
+            s = self.myopenrpg.get_component('settings')
+            s.save()
+        except: print "[WARNING] Error saving 'settings' component"
+
+        try:
+            self.map.pre_exit_cleanup()
+        except: print "[WARNING] Map error pre_exit_cleanup()"
+
+        try:
+            save_tree = string.upper(s.get_setting("SaveGameTreeOnExit"))
+            if  (save_tree <> "0") and (save_tree <> "FALSE") and (save_tree <> "NO"):
+                self.tree.save_tree(s.get_setting("gametree"))
+        except: print "[WARNING] Error saving gametree"
+
         if self.session.get_status() == orpg.networking.mplay_client.MPLAY_CONNECTED:
             self.kill_mplay_session()
+
+        #following lines added by mDuo13
+        #########close_module()#########
+        for plugin_fname in orpg.plugins.frame.enabled_plugins.keys():
+            plugin = orpg.plugins.frame.enabled_plugins[plugin_fname]
+            try:
+                plugin.close_module(self)
+            except Exception, e:
+                if str(e) != "'module' object has no attribute 'close_module'":
+                    #print e
+                    traceback.print_exc()
+        ####now, destroy the plugin window also###
+        orpg.plugins.frame.Destroy()
+        #end mDuo13 added code
+
         # destroy windows
         #if self.player_frame:
         #    self.player_frame.Destroy()
@@ -859,7 +909,7 @@ class orpgFrame(wxFrame):
         #    self.chat_frame = None
         #    self.map_frame.Destroy()
         #    self.map_frame = None
-        
+
         if self.gs_frame:
             self.gs_frame.Destroy()
         self.status_frame.Destroy()
@@ -937,7 +987,7 @@ class orpgFrame(wxFrame):
         dlg.ShowModal()
         dlg.Destroy()
 
-        
+
 #########################
 #status frame window
 #########################
@@ -953,7 +1003,7 @@ class status_bar(wxStatusBar):
         self.window = 1
         self.mainmenu = wxMenuBar()
         menu = wxMenu()
-        menu.Append(GENERAL_MENU,"General") 
+        menu.Append(GENERAL_MENU,"General")
         menu.Append(URL_MENU,"Url display")
 
         self.mainmenu.Append(menu,"Switch layout to...")
@@ -1008,11 +1058,11 @@ class status_bar(wxStatusBar):
         self.SetStatusText(st,2)
 
     def set_url(self,url):
-        self.urlis = url  
+        self.urlis = url
 
     def on_close(self,evt):
         self.Show( false )
- 
+
     def on_size(self,evt):
         s = self.GetClientSizeTuple()
         w = s[0]
