@@ -21,11 +21,11 @@
 # Author: OpenRPG
 # Maintainer:
 # Version:
-#   $Id: map.py,v 1.40 2003/05/28 01:55:12 snowdog_ Exp $
+#   $Id: map.py,v 1.43 2005/01/29 01:39:37 digitalxero Exp $
 #
 # Description:
 #
-__version__ = "$Id: map.py,v 1.40 2003/05/28 01:55:12 snowdog_ Exp $"
+__version__ = "$Id: map.py,v 1.43 2005/01/29 01:39:37 digitalxero Exp $"
 
 from map_version import MAP_VERSION
 from map_msg import *
@@ -43,7 +43,7 @@ from whiteboard_handler import *
 from background_handler import *
 from fog_handler import *
 
-from grid_handler import * 
+from grid_handler import *
 from map_handler import *
 
 ##-----------------------------
@@ -133,7 +133,7 @@ class map_canvas(wxScrolledWindow):
         # Used to check if we've used the user cache size value
         self.cacheSizeSet = 0
         self.inside = 0
-        
+
     def better_refresh(self):
         self.Refresh(false)
 
@@ -211,7 +211,8 @@ class map_canvas(wxScrolledWindow):
 
     def printscale(self):
         wxBeginBusyCursor()
-        dc = self.preppaint()
+        dc = wxClientDC(self)
+        self.PrepareDC(dc)
         dc.SetOptimization( true )
         self.showmapscale(dc)
         dc.SetOptimization( false )
@@ -227,7 +228,7 @@ class map_canvas(wxScrolledWindow):
                 self.frame.session.send(send_text)
             ##print "Sent:  %s" %  send_text
         else:
-            print "Send of no data in send_map_data() ignored"
+            print " of no data in send_map_data() ignored"
         wxEndBusyCursor()
 
 
@@ -252,7 +253,7 @@ class map_canvas(wxScrolledWindow):
         size=self.GetClientSize()
         unit=[10*scale,10*scale]
         if (unit[0]==0 or unit[1]==0):
-            return        
+            return
         pos[0]/=unit[0]
         pos[1]/=unit[1]
         mx=[int(self.size[0]*scale/unit[0])+1,int(self.size[1]*scale/unit[1]+1)]
@@ -290,7 +291,7 @@ class map_canvas(wxScrolledWindow):
         clientsize = self.GetClientSize()
         topleft1 = self.GetViewStart()
         topleft = [topleft1[0]*scrollsize[0],topleft1[1]*scrollsize[1]]
-        
+
         if (clientsize[0] > 1) and (clientsize[1] > 1):
             dc = wxMemoryDC()
             dc.BeginDrawing()
@@ -313,7 +314,7 @@ class map_canvas(wxScrolledWindow):
             dc.SelectObject(wxNullBitmap)
             dc.EndDrawing()
             del dc
-            
+
             wdc = self.preppaint()
             wdc.DrawBitmap(bmp,topleft[0],topleft[1])
             if self.frame.settings.get_setting("AlwaysShowMapScale") == "1":
@@ -324,10 +325,10 @@ class map_canvas(wxScrolledWindow):
         except:
             pass
         #self.inside = 0 #see above
-        
+
 
     def preppaint(self):
-        dc = wxPaintDC(self)        
+        dc = wxPaintDC(self)
         self.PrepareDC(dc)
         return (dc)
 
@@ -335,7 +336,7 @@ class map_canvas(wxScrolledWindow):
         scalestring = "Scale x" + `self.layers['grid'].mapscale`[:3]
         (textWidth,textHeight) = dc.GetTextExtent(scalestring)
         dc.SetUserScale(1,1)
-        dc.SetPen(wxLIGHT_GREY_PEN)        
+        dc.SetPen(wxLIGHT_GREY_PEN)
         dc.SetBrush(wxLIGHT_GREY_BRUSH)
         x = dc.DeviceToLogicalX(0)
         y = dc.DeviceToLogicalY(0)
@@ -790,12 +791,11 @@ class map_canvas(wxScrolledWindow):
             ##proc_dialog=wxProgressDialog( "Map Loading", "Map Loading, Please Wait...", 5, self )
             ##proc_dialog.Update( 0 )
 
-
             #parse the map DOM
             xml_dom = parseXml(xml)
             ##proc_dialog.Update( 1 )
-            
-            
+
+
             #print "number of uncollectables = " + str(gc.collect())
             node_list = xml_dom.getElementsByTagName("map")
 
@@ -825,7 +825,7 @@ class map_canvas(wxScrolledWindow):
                         self.layers['whiteboard'] = whiteboard_layer(self)
                     except:
                         pass
-                    try:                    
+                    try:
                         self.layers['fog'] = fog_layer(self)
                     except:
                         pass
@@ -853,7 +853,7 @@ class map_canvas(wxScrolledWindow):
                     if name == "fog":
                         self.layers[name].takedom(c)
 
-                        
+
                 for c in children:
                     name = c._get_nodeName()
                     if name != "fog":
@@ -862,7 +862,7 @@ class map_canvas(wxScrolledWindow):
                 # all map data should be converted, set map version to current version
                 self.map_version = MAP_VERSION
 
-                self.Refresh(false)  
+                self.Refresh(false)
             ##proc_dialog.Update( 4 )
 
             xml_dom.unlink()  # eliminate circular refs
@@ -895,9 +895,12 @@ class map_canvas(wxScrolledWindow):
             # have a whiteboard node.  As such, if it's not there, we'll just happily
             # move on and process as always.
             if tmp_map.children.has_key( "whiteboard" ):
+                print "whiteboard"
                 whiteboard_layer = tmp_map.children["whiteboard"]
                 if whiteboard_layer:
+                    print "IN RE_IDS"
                     lines = whiteboard_layer.get_children().keys()
+                    print "LINES",lines
                     if lines:
                         for line in lines:
                             l = whiteboard_layer.children[line]
@@ -945,26 +948,26 @@ class map_wnd(wxPanel):
         self.layer_tabs.AddPage(self.layer_handlers[5],"General")
 #        self.layer_handlers.append(fog_handler(self.layer_tabs,-1,self.canvas))
 #        self.layer_tabs.AddPage(self.layer_handlers[2],"Fog")
-        
+
         EVT_NOTEBOOK_PAGE_CHANGED(self.layer_tabs, LAYER_TABS, self.on_layer_change)
         EVT_SIZE(self, self.on_size)
-        
+
         self.load_default()
 
         # size of tabs is diffrent on windows and linux :(
-        
+
         if wxPlatform == '__WXMSW__':
             self.toolbar_height = 50
         else:
             self.toolbar_height = 60
-            
+
         self.layer_tabs.SetSelection(2)
 
     def load_default(self):
         session=self.session
         if session.is_connected() and (session.my_role() <> session.ROLE_GM) and (session.use_roles()):
             self.top_frame.myopenrpg.get_component("chat").InfoPost("You must be a GM to use this feature")
-            return        
+            return
         f = open(orpg.dirpath.dir_struct["template"]+"default_map.xml")
         self.new_data(f.read())
         f.close()
@@ -975,13 +978,13 @@ class map_wnd(wxPanel):
     def new_data(self,data):
         self.canvas.takexml(data)
         self.update_tools()
-        
+
     def on_save(self,evt):
         session=self.session
         if (session.my_role() <> session.ROLE_GM):
             self.top_frame.myopenrpg.get_component("chat").InfoPost("You must be a GM to use this feature")
             return
-        
+
         d =wxFileDialog(self.GetParent(),"Save map data",orpg.dirpath.dir_struct["user"],"","*.xml",wxSAVE)
         if d.ShowModal() == wxID_OK:
             f = open(d.GetPath(),"w")
@@ -999,7 +1002,7 @@ class map_wnd(wxPanel):
         if session.is_connected() and (session.my_role() <> session.ROLE_GM) and (session.use_roles()):
             self.top_frame.myopenrpg.get_component("chat").InfoPost("You must be a GM to use this feature")
             return
-        
+
         d =wxFileDialog(self.GetParent(),"Select a file",orpg.dirpath.dir_struct["user"],"","*.xml",wxOPEN)
         if d.ShowModal() == wxID_OK:
             f = open(d.GetPath())
@@ -1020,7 +1023,7 @@ class map_wnd(wxPanel):
 
     def on_layer_change(self,evt):
         self.current_layer = evt.GetSelection()
-        bg=self.layer_handlers[0]        
+        bg=self.layer_handlers[0]
         session=self.session
         if (session.my_role() <> session.ROLE_GM):
             bg.url_path.Show(false)
@@ -1044,7 +1047,7 @@ class map_wnd(wxPanel):
 
     def on_motion(self,evt):
         self.layer_handlers[self.current_layer].on_motion(evt)
-        
+
     def MapBar(self,id,data):
         self.canvas.MAP_MODE = data
         if id == 1:
@@ -1057,8 +1060,8 @@ class map_wnd(wxPanel):
         # do some pre exit clean up for bitmaps or other objects
         flushImageCache()
         self.canvas.pre_destory_cleanup()
-        
-        
+
+
     def update_tools(self):
         for h in self.layer_handlers:
             h.update_info()
