@@ -21,7 +21,7 @@
 # Author: Chris Davis
 # Maintainer:
 # Version:
-#   $Id: min_dialogs.py,v 1.12 2003/04/10 05:36:14 snowdog_ Exp $
+#   $Id: min_dialogs.py,v 1.14 2004/06/20 04:58:49 tdb30_ Exp $
 #
 # Description: This file contains some of the basic definitions for the chat
 # utilities in the orpg project.
@@ -209,9 +209,9 @@ class min_list_edit_dialog(wxDialog):
         self.grid = grid
         editor = min_list_edit_panel(self, min_index, min_list,layers)
         sizer.Add(wxButton(self, wxID_OK, "OK"), 1, wxEXPAND)
-        sizer.Add(10,10)
+        sizer.Add(wxSize(10,10))
 #        sizer.Add(wxButton(self, wxID_REVERT,"Reset"), 1, wxEXPAND)
-        sizer.Add(10,10)
+        sizer.Add(wxSize(10,10))
         sizer.Add(wxButton(self, wxID_CANCEL, "Cancel"), 1, wxEXPAND)
         (w,h) = self.GetClientSizeTuple()
         editor.SetDimensions(0,0,w,h-25)
@@ -262,11 +262,11 @@ class min_list_edit_panel(wxPanel):
             self.positioncombo.Append(`min_list[min_list.index(m)].pos`)
         listsizer.Add(wxStaticText(self, -1, "Path:"), 0, wxEXPAND)
         listsizer.Add(self.pathcombo, 0, wxEXPAND)
-        listsizer.Add(10,10)
+        listsizer.Add(wxSize(10,10))
         self.heading = wxRadioBox(self, MIN_HEADING, "Heading", choices=["None","N","NE","E","SE","S","SW","W","NW","no change"], majorDimension=5, style=wxRA_SPECIFY_COLS)
         self.heading.SetSelection( 9 )
         listsizer.Add( self.heading, 0, wxEXPAND )
-        listsizer.Add(10,10)
+        listsizer.Add(wxSize(10,10))
         self.face = wxRadioBox(self, MIN_FACE, "Facing", choices=["None","N","NE","E","SE","S","SW","W","NW","no change"], majorDimension=5, style=wxRA_SPECIFY_COLS)
         self.face.SetSelection(9)
         listsizer.Add(self.face, 0, wxEXPAND)
@@ -281,11 +281,11 @@ class min_list_edit_panel(wxPanel):
         self.snap = wxRadioBox(self,MIN_ALIGN,"Snap",choices=["Center","Top left","no change"],majorDimension=1,style=wxRA_SPECIFY_COLS)
         self.snap.SetSelection(2)
         group2.Add(self.locked, 0, wxEXPAND)
-        group2.Add(10,0)
+        group2.Add(wxSize(10,0))
         group2.Add(self.hide, 0, wxEXPAND)
-        group2.Add(10,0)
+        group2.Add(wxSize(10,0))
         group2.Add(self.snap, 0, wxEXPAND)
-        group2.Add(10,0)
+        group2.Add(wxSize(10,0))
         listsizer.Add(group2,0,0)
 ###
 ###     group together the postion radiobox and the and its selection elements
@@ -320,7 +320,7 @@ class min_list_edit_panel(wxPanel):
         ypos = wxStaticText(self, -1,"YPOS:  ")
         spinbox.Add(ypos,0, 0)
         spinbox.Add(self.scy, 0, 0)
-        poschoicebox.Add(0,15)
+        poschoicebox.Add(wxSize(0,15))
         poschoicebox.Add(spinbox,0,0)
             ###
             ### kludge is just a way to horizontaly position text.  .Add doesn't seem to work.
@@ -329,7 +329,7 @@ class min_list_edit_panel(wxPanel):
         klugetext = wxStaticText(self, -1, "            ")
         kluge.Add(klugetext,0,0)
         kluge.Add(self.positioncombo,0,0)
-        poschoicebox.Add(0,1)
+        poschoicebox.Add(wxSize(0,1))
         poschoicebox.Add(kluge,0,0)
         positionbox.Add(poschoicebox,0,0)
         listsizer.Add(positionbox,0, 0)
@@ -481,7 +481,7 @@ class min_edit_panel(wxPanel):
         self.label = orpgTextCtrl(self, MIN_LABEL, min.label)
         sizer.Add(wxStaticText(self, -1, "Label:"), 0, wxEXPAND)
         sizer.Add(self.label, 0, wxEXPAND)
-        sizer.Add(10,10)
+        sizer.Add(wxSize(10,10))
 
         self.heading = wxRadioBox(self, MIN_HEADING, "Heading", choices=["None","N","NE","E","SE","S","SW","W","NW"],majorDimension=5,style=wxRA_SPECIFY_COLS)
         self.heading.SetSelection(min.heading)
@@ -492,9 +492,9 @@ class min_edit_panel(wxPanel):
         self.hide = wxCheckBox(self, MIN_HIDE, " Hide")
         self.hide.SetValue(min.hide)
         sizer.Add(self.heading, 0, wxEXPAND)
-        sizer.Add(10,10)
+        sizer.Add(wxSize(10,10))
         sizer.Add(self.face, 0, wxEXPAND)
-        sizer.Add(10,10)
+        sizer.Add(wxSize(10,10))
 
         #
         #image resizing
@@ -503,7 +503,7 @@ class min_edit_panel(wxPanel):
         self.min_width = orpgTextCtrl(self, wxID_MIN_WIDTH, self.min_width_old_value)
         sizerSize.Add(wxStaticText(self, -1, "Width: "), 0, wxALIGN_CENTER)
         sizerSize.Add(self.min_width, 1, wxEXPAND)
-        sizerSize.Add(20, 25)
+        sizerSize.Add(wxSize(20, 25))
         #TODO:keep in mind that self.min is a local copy???
         self.min_height_old_value = str(self.min.bmp.GetHeight())
         self.min_height = orpgTextCtrl(self, wxID_MIN_HEIGHT, self.min_height_old_value)
@@ -514,11 +514,11 @@ class min_edit_panel(wxPanel):
         sizerSize.Add(self.min_scaling, 1, wxEXPAND)
 
         sizer.Add(sizerSize, 0, wxEXPAND)
-        sizer.Add(10, 10)
+        sizer.Add(wxSize(10, 10))
 
         # Now, add the last items on in their own sizer
         hSizer.Add(self.locked, 0, wxEXPAND)
-        hSizer.Add(10,10)
+        hSizer.Add(wxSize(10,10))
         hSizer.Add(self.hide, 0, wxEXPAND)
 
         # Add the hSizer to the main sizer
@@ -580,7 +580,7 @@ class min_edit_dialog(wxDialog):
         
         sizer =  wxBoxSizer(wxHORIZONTAL)
         sizer.Add(wxButton(self, wxID_OK, "OK"), 1, wxEXPAND)
-        sizer.Add(10,10)
+        sizer.Add(wxSize(10,10))
         sizer.Add(wxButton(self, wxID_CANCEL, "Cancel"), 1, wxEXPAND)
         sizer.SetDimension(0,h-25,w,25)
         mastersizer.Add(sizer, 0, wxEXPAND)
