@@ -21,11 +21,11 @@
 # Author: OpenRPG Team
 # Maintainer:
 # Version:
-#   $Id: miniatures_handler.py,v 1.17 2003/11/21 11:47:14 digitalxero Exp $
+#   $Id: miniatures_handler.py,v 1.19 2005/03/06 01:50:32 digitalxero Exp $
 #
 # Description: Miniature layer handler
 #
-__version__ = "$Id: miniatures_handler.py,v 1.17 2003/11/21 11:47:14 digitalxero Exp $"
+__version__ = "$Id: miniatures_handler.py,v 1.19 2005/03/06 01:50:32 digitalxero Exp $"
 
 
 from base_handler import *
@@ -105,11 +105,11 @@ class miniatures_handler(base_layer_handler):
 
 
         self.sizer.Prepend( createMaskedButton( self, orpg.dirpath.dir_struct["icon"]+'questionhead.gif', 'Edit miniature properties', MIN_LIST_TOOL ), 0, wxEXPAND )
-        self.sizer.Prepend(20,25)
+        self.sizer.Prepend(wxSize(20,25))
         self.sizer.Prepend(wxButton(self, MIN_TOOL, "Add Miniature", style=wxBU_EXACTFIT), 0, wxEXPAND)
         self.sizer.Prepend(self.min_url, 1, wxALIGN_CENTER)
         self.sizer.Prepend(auto_label,0,wxALIGN_CENTER)
-        self.sizer.Prepend(10,25)
+        self.sizer.Prepend(wxSize(10,25))
 
         #self.sizer.Fit(self)
         #self.SetAutoLayout(true)
@@ -297,15 +297,18 @@ class miniatures_handler(base_layer_handler):
             grid = self.canvas.layers['grid']
             grid_pos = grid.grid_hit_test(pos)
             if grid_pos:
-#                self.sel_min.pos = self.canvas.layers['grid'].get_top_corner(grid_pos)
-
-                topLeft = grid.get_top_corner(grid_pos)                                   #  get the top corner for this grid cell
+                topLeft = grid.get_top_corner(grid_pos)#  get the top corner for this grid cell
                 if self.sel_min.snap_to_align == SNAPTO_ALIGN_CENTER:
-                    x = topLeft.x + ((grid.unit_size - self.sel_min.bmp.GetWidth()) / 2)
-#  sets x such that the bitmap will be centered
-#  on the center of the grid cell
-                    y = topLeft.y + ((grid.unit_size_y - self.sel_min.bmp.GetHeight()) /2)
-#  ditto for y
+                    if grid.get_mode() == 1:
+                        x = ((topLeft.x/grid.size_ratio)-grid.unit_offset)+((grid.unit_widest/2) - (self.sel_min.bmp.GetWidth()/2))
+                        y = topLeft.y + ((grid.unit_size_y - self.sel_min.bmp.GetHeight()) /2)
+                    elif grid.get_mode() == 2:
+                        x = (topLeft.x)-(self.sel_min.bmp.GetWidth()/2)
+                        y = (topLeft.y)-(self.sel_min.bmp.GetHeight())
+                    else:
+                        x = topLeft.x + ((grid.unit_size - self.sel_min.bmp.GetWidth()) / 2)
+                        y = topLeft.y + ((grid.unit_size_y - self.sel_min.bmp.GetHeight()) /2)
+
                 else:
                     x = topLeft.x
                     y = topLeft.y
