@@ -21,16 +21,16 @@
 # Author: Chris Davis
 # Maintainer:
 # Version:
-#   $Id: whiteboard.py,v 1.21 2003/06/29 03:25:17 snowdog_ Exp $
+#   $Id: whiteboard.py,v 1.28 2005/10/23 19:19:46 tdb30_ Exp $
 #
 # Description: This file contains some of the basic definitions for the chat
 # utilities in the orpg project.
 #
-__version__ = "$Id: whiteboard.py,v 1.21 2003/06/29 03:25:17 snowdog_ Exp $"
+__version__ = "$Id: whiteboard.py,v 1.28 2005/10/23 19:19:46 tdb30_ Exp $"
 
 from base import *
 #from images import *
-
+from orpg.mapper.map_utils import *
 
 #MIN_STICKY_BACK = -0XFFFFFF
 #MIN_STICKY_FRONT = 0xFFFFFF
@@ -72,6 +72,187 @@ def cmp_zorder(first,second):
 
     return value
 
+class whiteboard_text(protectable_attributes):
+    def __init__(self, id,text_string ,pos, style, pointsize, weight, color="#000000"):
+        protectable_attributes.__init__(self)
+        self._protected_attr = ["weight", "pointsize","style","posx","posy","id","textcolor", "text_string"]
+        self.font = wxFont(int(pointsize), wxDEFAULT, int(style), int(weight), FALSE)
+        self.scale = 1
+        self.r_h = RGBHex()
+        self.textcolor = color
+        self.posx = pos.x
+        self.posy = pos.y
+        self.selected = false
+        self.text_string = text_string
+        self.id = id
+        self.weight = weight
+        self.pointsize = pointsize
+        self.style = style
+        #self._clean_all_attr()
+        self.highlighted = false
+        r,g,b = self.r_h.rgb_tuple(self.textcolor)
+        self.highlight_color = self.r_h.hexstring(r^255, g^255, b^255)
+
+    def highlight(self,highlight=true):
+            self.highlighted = highlight
+
+    def set_text_props(self,text_string, style, point, weight, color="#000000"):
+        self.text_string = text_string
+        self.font.SetStyle(int(style))
+        self.style = style
+        self.font.SetPointSize(int(point))
+        self.pointsize = point
+        self.font.SetWeight(int(weight))
+        self.weight = weight
+        self.textcolor = color
+        self._dirty_all_attr()
+
+    def hit_test(self, pt, dc):
+        rect = self.get_rect(dc)
+
+        result = None
+        # fixes problem between wxPython version 2.4.0.7 and higher
+        # and wxPython version 2.4.0.2 and lower --Snowdog
+        try: 
+           #2.4.0.7 and up check
+           result = rect.InsideXY(pt.x, pt.y)
+        except:
+           #2.4.0.2 and lower check
+           result = rect.Inside(pt.x, pt.y)
+        return result
+
+    def get_rect(self, dc):
+#        dc.SetFont(self.font)
+        (w,x,y,z) = dc.GetFullTextExtent(self.text_string)
+        return wxRect(self.posx,self.posy,w,(x+y+z))
+
+    def draw(self,parent, dc, op = wxCOPY):
+        self.scale = parent.canvas.layers['grid'].mapscale
+        if self.highlighted:
+            textcolor = self.highlight_color
+        else:
+            textcolor = self.textcolor
+
+        try:
+            r,g,b = self.r_h.rgb_tuple(textcolor)
+            color = wxColour(r,g,b)
+            dc.SetTextForeground(color)
+        except Exception,e:
+                dc.SetTextForeground(wxColour(0,0,0))
+
+        dc.SetOptimization( true )
+        dc.SetUserScale(self.scale,self.scale)
+        dc.BeginDrawing()
+
+# Draw text
+        (w,x,y,z) = self.get_rect(dc)
+        dc.DrawText(self.text_string, self.posx, self.posy)
+        dc.EndDrawing()
+        dc.SetTextForeground(wxColour(0,0,0))
+        dc.SetOptimization( false )
+
+
+    def toxml(self, action = "update",preserve_changed=0):
+
+        xml_str = ""
+
+        if preserve_changed:
+            original_changed = self._changed_attr()
+
+        if action == "del":
+            xml_str = "<text action='del' id='" + self.id + "'/>"
+            return xml_str
+        if action == "new":
+            self._dirty_all_attr()
+
+        changed = self._changed_attr()
+
+        if changed:
+
+            #  if there are any changes, make sure id is one of them
+            if not changed.has_key("id"):
+                self._dirty_attr("id")
+                changed = self._changed_attr()
+
+            xml_str = "<text"
+
+            xml_str += " action='" + action + "'"
+
+            for a in changed.keys():
+                if a == "pointsize":
+                    if not(self.pointsize is None):
+                        xml_str += " pointsize='" + str(self.font.GetPointSize()) + "'"
+                if a == "style":
+                    if not (self.style is None):
+                        xml_str += " style='" + str(self.font.GetStyle()) + "'"
+                if a == "weight":
+                    if not (self.weight is None):
+                        xml_str += " weight='" + str(self.font.GetWeight()) + "'"
+                if a == "id":
+                    if not (self.id is None):
+                        xml_str += " id='" + self.id + "'"
+                if a == "posx":
+                    if not(self.posx is None):
+                        xml_str+= " posx='" + str(self.posx) + "'"
+                if a == "text_string":
+                    if not (self.text_string is None):
+                        xml_str+= " text_string='" + self.text_string + "'"
+                if a == "textcolor":
+                    if not (self.textcolor is None):
+                        xml_str += " color='" + str(self.textcolor) + "'"
+                if a == "posy":
+                    if not (self.posy is None):
+                        xml_str += " posy='" + str(self.posy) + "'"
+            xml_str += "/>"
+        self._clean_all_attr()
+
+        if preserve_changed:
+            for a in original_changed.keys():
+                self._dirty_attr(a)
+        return xml_str
+
+    def takedom(self,xml_dom):
+        text_string = xml_dom.getAttribute("text_string")
+        if text_string <> "":
+            self.text_string = text_string
+        posy = xml_dom.getAttribute("posy")
+        if posy <> "":
+            self.posy = int(posy)
+            self._clean_attr("posy")
+        posx = xml_dom.getAttribute("posx")
+        if posx <> "":
+            self.posx = int(posx)
+            self._clean_attr("posx")
+        weight = xml_dom.getAttribute("weight")
+        if weight <> "":
+            self.weight = weight
+            self.font.SetWeight(int(weight))
+            self._clean_attr("weight")
+        style = xml_dom.getAttribute("style")
+        if style <> "":
+            self.style = style
+            self.font.SetStyle(int(style))
+            self._clean_attr("style")
+        pointsize = xml_dom.getAttribute("pointsize")
+        if pointsize <> "":
+            self.pointsize = pointsize
+            self.font.SetPointSize(int(pointsize))
+            self._clean_attr("pointsize")
+
+        id = xml_dom.getAttribute("id")
+        if id <> "":
+            self.id = id
+            self._clean_attr("id")
+        color = xml_dom.getAttribute("color")
+        if color <> "":
+#            r,g,b = self.r_h.rgb_tupple(color)
+            self.textcolor = color
+#            self.set_color(cmpColour(r,g,b))
+            self._clean_attr("color")
+            
+
+
+
 class whiteboard_line(protectable_attributes):
     def __init__(self, id,line_string,upperleft,lowerright,color="#000000",width=1):
         protectable_attributes.__init__(self)
@@ -87,7 +268,12 @@ class whiteboard_line(protectable_attributes):
         self.line_string = line_string
         self.id = id
         #self._clean_all_attr()
+        self.highlighted = false
+        r,g,b = self.r_h.rgb_tuple(self.linecolor)
+        self.highlight_color = self.r_h.hexstring(r^255, g^255, b^255)
 
+    def highlight(self,highlight=true):
+        self.highlighted = highlight 
 
     def set_line_props(self,line_string = "",upperleftx=0,upperlefty=0,lowerrightx=0,lowerrighty=0,color="#000000",width=1):
         self.line_string = line_string
@@ -99,43 +285,36 @@ class whiteboard_line(protectable_attributes):
         self.linewidth = width
 
     def hit_test(self, pt):
-        closestpoint = 999
-        xm = pt.x
-        ym = pt.y
         coords = self.line_string.split(";")
-        for m in range(len(coords)-2):
-            xy1 = coords[m].split(",")
-            x1 = int(xy1[0])
-            y1 = int(xy1[1])
-            xy2 = coords[m+1].split(",")
-            x2 = int(xy2[0])
-            y2 = int(xy2[1])
-            numerator = (y1-y2)*xm +(x2-x1)*ym +(x1*y2-x2*y1)
-            denominator = ((x2-x1)*(x2-x1)+(y2-y1)*(y2-y1))**0.5
-            if denominator <> 0:
-                distance = abs(numerator /denominator)
-                if distance < closestpoint:
-                    closestpoint = distance
-        margin = .5
-        if closestpoint < margin:
-            return closestpoint
-        else:
-            return -1
+        stcords = coords[0].split(",")
+        oldicords = (int(stcords[0]),int(stcords[1]))
+        for coordinate_string_counter in range(1,len(coords)):
+            stcords = coords[coordinate_string_counter].split(",")
+            if stcords[0] == "":
+                return false
+            icords = (int(stcords[0]),int(stcords[1]))
+            if orpg.mapper.map_utils.proximity_test(oldicords,icords,pt,12):
+                return true
+            oldicords = icords
+            
+        return false
 
     def draw(self,parent, dc, op = wxCOPY):
         self.scale = parent.canvas.layers['grid'].mapscale
-
+        if self.highlighted:
+            linecolor = self.highlight_color
+        else:
+            linecolor = self.linecolor
         pen = wxBLACK_PEN
         try:
-            if self.linecolor <> "#000000":
-                r,g,b = self.r_h.rgb_tuple(self.linecolor)
+            if linecolor <> "#000000":
+                r,g,b = self.r_h.rgb_tuple(linecolor)
                 color = wxColour(r,g,b)
                 pen.SetColour(color)
             else:
                 pen.SetColour(wxColour(0,0,0))
         except Exception,e:
                 pen.SetColour(wxColour(0,0,0))
-        #print self.linewidth
         pen.SetWidth( self.linewidth )
         dc.SetPen( pen )
         dc.SetBrush( wxBLACK_BRUSH )
@@ -161,22 +340,7 @@ class whiteboard_line(protectable_attributes):
         dc.SetPen(wxNullPen)
         dc.SetBrush(wxNullBrush)
         dc.SetOptimization( false )
-
         #selected outline
-        if self.selected:
-            dc.SetPen(wxRED_PEN)
-            dc.SetBrush(wxTRANSPARENT_BRUSH)
-            dc.DrawLine(self.upperleft.x, self.upperleft.y, self.lowerright.x,self.scale*self.upperleft.y)
-            dc.DrawLine(self.upperleft.x, self.upperleft.y,self.upperleft.x, self.scale*self.lowerright.y)
-            dc.DrawLine(self.lowerright.x,self.lowerright.y, self.lowerright.x,self.scale*self.upperleft.y)
-            dc.DrawLine(self.lowerright.x,self.lowerright.y, self.upperleft.x, self.scale*self.lowerright.y)
-
-            dc.SetBrush(wxNullBrush)
-            dc.SetPen(wxNullPen)
-
-            return true
-        else:
-            return false
 
     def toxml(self, action = "update",preserve_changed=0):
 
@@ -224,7 +388,7 @@ class whiteboard_line(protectable_attributes):
                     if not (self.linecolor is None):
                         xml_str += " color='" + str(self.linecolor) + "'"
                 if a == "linewidth":
-		    if not (self.linewidth is None):
+                    if not (self.linewidth is None):
                         xml_str += " width='" + str(self.linewidth) + "'"
             xml_str += "/>"
         self._clean_all_attr()
@@ -272,6 +436,7 @@ class whiteboard_line(protectable_attributes):
         self.linewidth = int(width)
 
 
+
 ##-----------------------------
 ## whiteboard layer
 ##-----------------------------
@@ -293,6 +458,7 @@ class whiteboard_layer(layer_base):
         self.r_h = RGBHex()
         self.id = -1
         self.lines = []
+        self.texts = []
         #self.line_string = "0,0;"
         #self.upperleft = wxPoint(0,0)
         #self.lowerright = wxPoint(0,0)
@@ -300,7 +466,6 @@ class whiteboard_layer(layer_base):
         self.color = "#000000"
         self.width = 1
         self._clean_all_attr()
-       
 
     def next_serial( self ):
         self.serial_number += 1
@@ -310,38 +475,11 @@ class whiteboard_layer(layer_base):
         z = len(self.lines)+1
         return z
 
-
     def cleanly_collapse_zorder(self):
-        #  lock the zorder stuff
         pass
-#        sorted_miniatures = self.miniatures[:]
-#        sorted_miniatures.sort(cmp_zorder)
-#        i = 0
-#        for mini in sorted_miniatures:
-#            mini.zorder = i
-#            i = i + 1
-#            mini._clean_attr("zorder")
-
-        #  unlock the zorder stuff
-
-
 
     def collapse_zorder(self):
-        #  lock the zorder stuff
         pass
-#        sorted_miniatures = self.miniatures[:]
-#        sorted_miniatures.sort(cmp_zorder)
-#        i = 0
-#        for mini in sorted_miniatures:
-#            if (mini.zorder != MIN_STICKY_BACK) and (mini.zorder != MIN_STICKY_FRONT):
-##                print "zorder is " + str(mini.zorder) + " and is being set to " + str(i)
-#                mini.zorder = i
-#            else:
-#                print "sticky item found having value of " + str( mini.zorder)
-#            i = i + 1
-        #  unlock the zorder stuff
-
-
 
     def rollback_serial( self ):
         self.serial_number -= 1
@@ -353,14 +491,13 @@ class whiteboard_layer(layer_base):
         line = whiteboard_line(id,line_string,upperleft,lowerright,color=self.color,width=self.width)
         self.lines.append(line)
         line._dirty_all_attr()
-        #print self
 
         xml_str = "<map><whiteboard>"
         xml_str += line.toxml("new")
         xml_str += "</whiteboard></map>"
-        #print xml_str
         self.canvas.frame.session.send(xml_str)
         self.canvas.Refresh(false)
+        return line
 
     def get_line_by_id(self,id):
 
@@ -369,6 +506,12 @@ class whiteboard_layer(layer_base):
                 return line
         return None
 
+    def get_text_by_id(self,id):
+        for text in self.texts:
+            if text.id == id:
+                return text
+        return None
+
     def del_line(self,line):
         xml_str = "<map><whiteboard>"
         xml_str += line.toxml("del")
@@ -379,22 +522,46 @@ class whiteboard_layer(layer_base):
         self.canvas.Refresh(false)
 #        self.collapse_zorder()
 
+    def del_text(self,text):
+        xml_str = "<map><whiteboard>"
+        xml_str += text.toxml("del")
+        xml_str += "</whiteboard></map>"
+        self.canvas.frame.session.send(xml_str)
+        if text:
+            self.texts.remove(text)
+        self.canvas.Refresh(false)
+#        self.collapse_zorder()
+
     def draw(self,dc):
-        #print self
         for m in self.lines:
             m.draw(self,dc)
+        for m in self.texts:
+            m.draw(self,dc)
+
+    def hit_test_text(self,pos, dc):
+        list_of_texts_matching = []
+        for m in self.texts:
+            if m.hit_test(pos,dc):
+                list_of_texts_matching.append(m)
+        return list_of_texts_matching
+
+    def hit_test_lines(self,pos,dc):
+        list_of_lines_matching = []
+        for m in self.lines:
+            if m.hit_test(pos):
+                list_of_lines_matching.append(m)
+        return list_of_lines_matching
 
     def find_line(self, pt):
-        line = None
-        closest = 999
-        for m in self.lines:
-            distance = m.hit_test(pt)
-            if (distance <> -1) and (distance < closest):
-                line = m
-        if line:
-            return line
+        scale = self.canvas.layers['grid'].mapscale
+        dc = wxClientDC( self.canvas )
+        self.canvas.PrepareDC( dc )
+        dc.SetUserScale(scale,scale)
+        line_list = self.hit_test_lines(pt,dc)
+        if line_list:
+            return line_list[0]
         else:
-            return None
+            return None 
 
     def setcolor(self,color):
         r,g,b = color.Get()
@@ -405,18 +572,33 @@ class whiteboard_layer(layer_base):
     
     def setwidth(self,width):
         self.width = int(width)
-        #print width
+
+    def set_font(self,font):
+        self.font = font
+
+    def add_text(self,text_string,pos, style, pointsize, weight, color = "#000000"):
+        id =self.canvas.frame.session.get_next_id()
+        text = whiteboard_text(id,text_string, pos, style, pointsize, weight, color)
+        self.texts.append(text)
+        text._dirty_all_attr()
+        xml_str = "<map><whiteboard>"
+        xml_str += text.toxml("new")
+        xml_str += "</whiteboard></map>"
+
+        self.canvas.frame.session.send(xml_str)
+        self.canvas.Refresh(false)
 
     def draw_working_line(self, dc, line_string):
         scale = self.canvas.layers['grid'].mapscale
 
         dc.SetPen( wxBLACK_PEN )
+        dc.SetBrush( wxBLACK_BRUSH )
         pen = wxBLACK_PEN
         r,g,b = self.r_h.rgb_tuple(self.color)
         color = wxColour(r,g,b)
         pen.SetColour(color)
         pen.SetWidth(self.width)
-        dc.SetBrush( wxBLACK_BRUSH )
+        dc.SetPen(pen)
         dc.SetOptimization( true )
         dc.SetUserScale(scale,scale)
         dc.BeginDrawing()
@@ -439,7 +621,6 @@ class whiteboard_layer(layer_base):
 
     def toxml(self,action="update"):
         """ format  """
-
         attributes = ""
         if action == "new":
             self._dirty_all_attr()
@@ -451,17 +632,19 @@ class whiteboard_layer(layer_base):
                     attributes += " serial='" + str(self.serial_number) + "'"
                     self._clean_attr("serial_number")
 
-        lines_string = ""
+        white_string = ""
         if self.lines:
             for l in self.lines:
-                lines_string += l.toxml(action)
-
-        if lines_string or changed:
+                white_string += l.toxml(action)
+        if self.texts:
+            for l in self.texts:
+                white_string += l.toxml(action)
+        if white_string or changed:
             s = "<whiteboard"
             s += attributes
-            if lines_string:
+            if white_string:
                 s += ">"
-                s += lines_string
+                s += white_string
                 s += "</whiteboard>"
             else:
                 s+="/>"
@@ -472,16 +655,13 @@ class whiteboard_layer(layer_base):
             return ""
 
     def takedom(self,xml_dom):
-
         serial_number = xml_dom.getAttribute('serial')
         if serial_number <> "":
             self.serial_number = int(serial_number)
             self._clean_attr("serial_number")
-
         children = xml_dom._get_childNodes()
         for l in children:
-
-  
+            nodename = l._get_nodeName()
   #      lines = xml_dom.getElementsByTagName("line")
   #      for l in lines:
 
@@ -492,8 +672,11 @@ class whiteboard_layer(layer_base):
                 line = self.get_line_by_id(id)
                 if line:
                     self.lines.remove(line)
+                text = self.get_text_by_id(id)
+                if text:
+                    self.texts.remove(text)
                 else:
-                    print "Whiteboard error: Deletion of unknown line attempted."
+                    print "Whiteboard error: Deletion of unknown whiteboard object attempted."
                     #wxMessageBox("Deletion of unknown line attempted","Map Synchronization Error")
 
 
@@ -501,36 +684,65 @@ class whiteboard_layer(layer_base):
 #                pos = cmpPoint(int(c.getAttribute('posx')),int(c.getAttribute('posy')))
 #                path = c.getAttribute('path')
 #                label = c.getAttribute('label')
-                try:
-                    line_string = l.getAttribute('line_string')
-                    upperleftx = l.getAttribute('upperleftx')
-                    upperlefty = l.getAttribute('upperlefty')
-                    lowerrightx = l.getAttribute('lowerrightx')
-                    lowerrighty = l.getAttribute('lowerrighty')
-                    upperleft = wxPoint(int(upperleftx),int(upperlefty))
-                    lowerright = wxPoint(int(lowerrightx),int(lowerrighty))
-                    color = l.getAttribute('color')
-                    id = l.getAttribute('id')
+                name = l._get_nodeName()
+                if name == "line":
+                    try:
+                        line_string = l.getAttribute('line_string')
+                        upperleftx = l.getAttribute('upperleftx')
+                        upperlefty = l.getAttribute('upperlefty')
+                        lowerrightx = l.getAttribute('lowerrightx')
+                        lowerrighty = l.getAttribute('lowerrighty')
+                        upperleft = wxPoint(int(upperleftx),int(upperlefty))
+                        lowerright = wxPoint(int(lowerrightx),int(lowerrighty))
+                        color = l.getAttribute('color')
+                        id = l.getAttribute('id')
                     
-                    #fix problem with older clients not supplying the line weight variable
-                    width = 1
-                    try: width = int(l.getAttribute('width'))
-                    except: pass
+                        #fix problem with older clients not supplying the line weight variable
+                        width = 1
+                        try: width = int(l.getAttribute('width'))
+                        except: pass
                     
-                except:
-                    line_string = upperleftx = upperlefty = lowerrightx = lowerrighty = color = 0
-                    print "invalid line"
-                    continue
-                line = whiteboard_line(id, line_string, upperleft,lowerright,color,width)
-                self.lines.append(line)
+                    except:
+                        line_string = upperleftx = upperlefty = lowerrightx = lowerrighty = color = 0
+                        print "invalid line"
+                        continue
+                    line = whiteboard_line(id, line_string, upperleft,lowerright,color,width)
+                    self.lines.append(line)
+                elif name == "text":
+                    try:
+                        text_string = l.getAttribute('text_string')
+                        style = l.getAttribute('style')
+                        pointsize = l.getAttribute('pointsize')
+                        weight = l.getAttribute('weight')
+                        color = l.getAttribute('color')
+                        id = l.getAttribute('id')
+                        posx = l.getAttribute('posx')
+                        posy = l.getAttribute('posy')
+                        pos = wxPoint(0,0)
+                        pos.x = int(posx)
+                        pos.y = int(posy)
+                    except Exception, e:
+                        print e
+                        print "invalid text"
+                        continue
+                    text = whiteboard_text(id,text_string, pos, style, pointsize, weight, color)
+                    self.texts.append(text)
 
             else:
-                line = self.get_line_by_id(id)
-                if line:
-                    line.takedom(l)
-                else:
-                    print "Whiteboard error: Update of unknown line attempted."
-                    #wxMessageBox("Update of unknown line attempted","Map Synchronization Error")
-
+                name = l._get_nodeName()
+                if name == "line":
+                    line = self.get_line_by_id(id)
+                    if line:
+                        line.takedom(l)
+                    else:
+                        print "Whiteboard error: Update of unknown line attempted."
+                        #wxMessageBox("Update of unknown line attempted","Map Synchronization Error")
+                if name == "text":
+                    print "removing text"
+                    text = self.get_text_by_id(id)
+                    if text:
+                        text.takedom(l)
+                    else:
+                        print "Whiteboard error: Update of unknown line attempted."
         #self.canvas.send_map_data()
         
