@@ -21,12 +21,12 @@
 # Author: Chris Davis
 # Maintainer:
 # Version:
-#   $Id: gsclient.py,v 1.23 2003/11/21 22:22:43 digitalxero Exp $
+#   $Id: gsclient.py,v 1.34 2005/10/24 01:07:27 tdb30_ Exp $
 #
 # Description: The file contains code for the game server browser
 #
 
-__version__ = "$Id: gsclient.py,v 1.23 2003/11/21 22:22:43 digitalxero Exp $"
+__version__ = "$Id: gsclient.py,v 1.34 2005/10/24 01:07:27 tdb30_ Exp $"
 
 import orpg.dirpath
 from orpg.orpg_windows import *
@@ -55,6 +55,42 @@ GS_CLOSE = wxNewId()
 OR_CLOSE = wxNewId()
 
 
+class server_instance:
+    def __init__(self, id, name="[Unknown]", users="0", address="127.0.0.1", port="6774"):
+        self.id = id
+        self.name = name
+        self.user = users
+        self.addy = address
+        self.port = port
+
+def server_instance_compare(x,y):
+    """compares server insances for list sort"""
+    DEV_SERVER = "OpenRPG DEV"
+    xuser = 0
+    yuser = 0
+    try: xuser = int(x.user)
+    except: pass
+    try: yuser = int(y.user)
+    except: pass
+
+    if x.name.startswith(DEV_SERVER):
+        if y.name.startswith(DEV_SERVER):
+            if x.name > y.name: return 1
+            elif x.name == y.name:
+                if xuser < yuser: return 1
+                elif xuser > yuser: return -1
+                else: return 0
+            else: return -1
+        else: return -1
+    elif y.name.startswith(DEV_SERVER): return 1
+    elif xuser < yuser: return 1
+    elif xuser == yuser:
+        if x.name > y.name: return 1
+        elif x.name == y.name: return 0
+        else: return -1
+    else: return -1
+
+
 class game_server_panel(wxPanel):
     def __init__(self,parent,openrpg):
         wxPanel.__init__(self, parent, -1)
@@ -68,6 +104,7 @@ class game_server_panel(wxPanel):
         self.last_motd = ""
         self.buttons = {}
         self.texts = {}
+        self.svrList = []
         self.build_ctrls()
         self.refresh_server_list()
         self.refresh_room_list()
@@ -87,8 +124,8 @@ class game_server_panel(wxPanel):
 
 
         ## fixed size Boxed Sizers
-        self.box_sizers["c_room"].SetSize( wxSize(200,125) )
-        self.box_sizers["window"].SetSize( wxSize(200,60) )
+        self.box_sizers["c_room"].SetMySize( wxSize(200,125) )
+        self.box_sizers["window"].SetMySize( wxSize(200,60) )
 
 
         ## Layout Sizers
@@ -212,6 +249,11 @@ class game_server_panel(wxPanel):
         EVT_BUTTON(self, OR_CLOSE, self.on_button)
         EVT_CHECKBOX(self, GS_PWD, self.on_button)
 
+
+        # Added double click handlers 5/05 -- Snowdog
+        EVT_LIST_ITEM_ACTIVATED(self, LIST_SERVER, self.on_server_dbclick)
+        EVT_LIST_ITEM_ACTIVATED(self, LIST_ROOM, self.on_room_dbclick)
+
         EVT_LIST_ITEM_SELECTED(self,LIST_ROOM,self.on_select)
         EVT_LIST_ITEM_SELECTED(self,LIST_SERVER,self.on_select)
         EVT_SET_FOCUS(self.texts['address'],self.on_text)
@@ -225,6 +267,51 @@ class game_server_panel(wxPanel):
 
 
 
+    #-----------------------------------------------------
+    # on_server_dbclick()
+    # support for double click selection of server.
+    # 5/16/05 -- Snowdog
+    #-----------------------------------------------------
+    def on_server_dbclick(self, evt):
+        #make sure address is updated just in case list select wasn't done
+        self.on_select(evt)
+        address = self.texts["address"].GetValue()
+        if self.session.is_connected():
+            if self.session.host_server == address :
+                #currently connected to address. Do nothing.
+                return
+            else:
+                #address differs, disconnect.
+                self.frame.kill_mplay_session()
+        self.do_connect(address)
+
+
+    #-----------------------------------------------------
+    # on_room_dbclick()
+    # support for double click selection of server.
+    # 5/16/05 -- Snowdog
+    #-----------------------------------------------------
+    def on_room_dbclick(self, evt):
+        #make sure address is updated just in case list select wasn't done
+        self.on_select(evt)
+
+        if self.cur_room_index >= 0:
+            if self.cur_room_index != 0:
+                self.set_lobbybutton(1);
+            else:
+                self.set_lobbybutton(0);
+
+            group_id = str(self.room_list.GetItemData(self.cur_room_index))
+            group = self.session.get_group_info(group_id)
+            pwd = ""
+            if (group[2] == "True") or (group[2] == "1"):
+                pwd = self.password_manager.GetPassword("room", group_id)
+            else:
+                pwd = ""
+            self.session.send_join_group(group_id,pwd)
+
+
+
     def on_select(self,evt):
         id = evt.GetId()
         if id == LIST_ROOM:
@@ -232,10 +319,14 @@ class game_server_panel(wxPanel):
         elif id==LIST_SERVER:
             #self.cur_server_index = self.server_list.GetSelection()
             self.cur_server_index = evt.m_itemIndex
-            self.name = self.servers[self.cur_server_index].getAttribute('name')
-            address = self.servers[self.cur_server_index].getAttribute('address')
-            port = self.servers[self.cur_server_index].getAttribute('port')
-            self.texts["address"].SetValue(address+":"+port)
+
+            self.name = self.svrList[self.cur_server_index].name
+            address = self.svrList[self.cur_server_index].addy
+            port = self.svrList[self.cur_server_index].port
+            #self.name = self.servers[self.cur_server_index].getAttribute('name')
+            #address = self.servers[self.cur_server_index].getAttribute('address')
+            #port = self.servers[self.cur_server_index].getAttribute('port')
+            self.texts["address"].SetValue(address+":"+str(port))
 
     def on_text(self,evt):
         id = evt.GetId()
@@ -344,7 +435,7 @@ class game_server_panel(wxPanel):
             # __name__ or something
 
             # print self.parent.__name__ # this didn't work
-            print self.parent.__dict__  # this *might* be coerced into working
+            # print self.parent.__dict__  # this *might* be coerced into working
             # print self.parent.locals() # this didn't work
 
             # print 'browse panel closing'
@@ -377,28 +468,55 @@ class game_server_panel(wxPanel):
         #dlg = do_progress_dlg(self,"Game Browser","Retrieving  Server List...",5)
 
         try:
+            self.svrList = []
             self.server_list.DeleteAllItems()
             xml_dom = meta_server_lib.get_server_list(["2"]);
             #dlg.Update(1,"Parsing list...")
             node_list = xml_dom.getElementsByTagName('server')
             #dlg.Update(2)
 
+            hex = orpg.tools.rgbhex.RGBHex()
+            color1 = self.settings.get_setting("RoomColor_Active")
+            color2 = self.settings.get_setting("RoomColor_Locked")
+            color3 = self.settings.get_setting("RoomColor_Empty")
+            color4 = self.settings.get_setting("RoomColor_Lobby")
+
             if len(node_list):
                 length = len(node_list)
                 part = 0
                 partLength = 1.0/length
 
+
+
                 for n in node_list:
+                    if n.hasAttribute('id') and n.hasAttribute('name') and n.hasAttribute('num_users') and n.hasAttribute('address') and n.hasAttribute('port'):
+                        self.svrList.append( server_instance(n.getAttribute('id'),n.getAttribute('name'), n.getAttribute('num_users'), n.getAttribute('address'),n.getAttribute('port')))
+
+                self.svrList.sort(server_instance_compare)
+
+                for n in self.svrList:
                     i = self.server_list.GetItemCount()
-                    name = n.getAttribute('name')
-                    if n.hasAttribute('num_users'):
-                        players = n.getAttribute('num_users')
-                    else:
-                        players = "N/A"
+                    name = n.name
+                    players = n.user
 
                     self.server_list.InsertStringItem(i,players)
                     self.server_list.SetStringItem(i,1,name)
 
+                    r,g,b = hex.rgb_tuple(color1)
+                    svrcolor = wxColour(red=r,green=g,blue=b)
+
+                    if players == "0":
+                        r,g,b = hex.rgb_tuple(color3)
+                        svrcolor = wxColour(red=r,green=g,blue=b)
+
+                    if n.name.startswith("OpenRPG DEV"):
+                        r,g,b = hex.rgb_tuple(color2)
+                        svrcolor = wxColour(red=r,green=g,blue=b)
+
+                    item = self.server_list.GetItem(i)
+                    item.SetTextColour(svrcolor)
+                    self.server_list.SetItem(item)
+
                     part += partLength
 
                     #  wxProgressDialog.Update takes an int
@@ -452,7 +570,7 @@ class game_server_panel(wxPanel):
 
         except Exception, e:
             print "Server List not available."
-            print e
+            traceback.print_exc()
 
         #dlg.Update(4,"Done.")
 
@@ -500,7 +618,8 @@ class game_server_panel(wxPanel):
                 #dlg.Destroy()
             else:
                 pwd = ""
-            self.session.send_join_group(group_id,pwd)
+            if pwd != None:#pwd==None means the user clicked "Cancel"
+                self.session.send_join_group(group_id,pwd)
 
 
     def do_create_group(self):
@@ -511,16 +630,37 @@ class game_server_panel(wxPanel):
         #
         # Check for & in name.  We want to allow this becaus of its common use in D&D.
         #
+
         loc = name.find("&")
         oldloc=0
-        while loc >0:
-            print loc,name
+        while loc > -1:
             loc = name.find("&",oldloc)
-            if loc >0:
+            if loc > -1:
                 b = name[:loc]
                 e = name[loc+1:]
                 name = b + "&amp;" + e
                 oldloc = loc+1
+
+        loc = name.find('"')
+        oldloc=0
+        while loc > -1:
+            loc = name.find('"',oldloc)
+            if loc > -1:
+                b = name[:loc]
+                e = name[loc+1:]
+                name = b + "&#39;&#39;" + e
+                oldloc = loc+1
+        loc = name.find("'")
+        oldloc=0
+        while loc > -1:
+            loc = name.find("'",oldloc)
+            if loc > -1:
+                b = name[:loc]
+                e = name[loc+1:]
+                name = b + "&#39;" + e
+                oldloc = loc+1
+
+
         if self.buttons[GS_PWD].GetValue():
             pwd = self.texts["room_pwd"].GetValue()
         else:
@@ -531,6 +671,7 @@ class game_server_panel(wxPanel):
             msg = "%s is creating room \'%s.\'" % (self.session.name, name)
             self.session.send( msg )
             self.session.send_create_group(name,pwd,boot_pwd,minversion)
+            self.set_lobbybutton(1); #enable the Lobby quickbutton
 
 
 #---------------------------------------------------------
@@ -579,9 +720,8 @@ class game_server_panel(wxPanel):
                     r,g,b = hex.rgb_tuple(color1)
                     color = wxColour(red=r,green=g,blue=b)
 
-
                     #passworded rooms with players get marked in dark red
-                    if gr[2]=="1":
+                    if gr[2]=="1" or gr[2]=="True":
                         r,g,b = hex.rgb_tuple(color2)
                         color = wxColour(red=r,green=g,blue=b)
 
@@ -599,9 +739,3 @@ class game_server_panel(wxPanel):
                     self.room_list.SetItem(item)
         except:
             traceback.print_exc()
-
-
-
-
-
-
