@@ -1,7 +1,7 @@
 #!/usr/bin/python2.1
 # Copyright (C) 2000-2001 The OpenRPG Project
 #
-#	openrpg-dev@lists.sourceforge.net
+# openrpg-dev@lists.sourceforge.net
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,16 +22,16 @@
 # Author: Chris Davis
 # Maintainer:
 # Version:
-#   $Id: meta_server_lib.py,v 1.28 2003/12/06 01:20:39 snowdog_ Exp $
+#   $Id: meta_server_lib.py,v 1.31 2005/06/05 20:12:38 digitalxero Exp $
 #
 # Description: A collection of functions to communicate with the meta server.
 #
 
 
 #added debug flag for meta messages to cut console server spam --Snowdog
-META_DEBUG = 0 
+META_DEBUG = 0
 
-__version__ = "$Id: meta_server_lib.py,v 1.28 2003/12/06 01:20:39 snowdog_ Exp $"
+__version__ = "$Id: meta_server_lib.py,v 1.31 2005/06/05 20:12:38 digitalxero Exp $"
 
 from orpg.orpg_version import PROTOCOL_VERSION
 from orpg.orpg_xml import *
@@ -44,6 +44,7 @@ import time
 import sys
 import random
 import traceback
+import re
 
 metacache_lock = RLock()
 
@@ -63,6 +64,14 @@ def get_server_dom(data=None,path=None):
 #    print
     file = urllib.urlopen(path,data)
     data = file.read()
+
+    # Remove any leading or trailing data.  This can happen on some satellite connections
+
+    p = re.compile('(<servers>.*?</servers>)',re.DOTALL|re.IGNORECASE)
+    mo=p.search(data)
+    if mo:
+        data=mo.group(0)
+
 #    print
 #    print "Got this string from the Meta at " + path + ":"
 #    print "==============================================="
@@ -633,7 +642,7 @@ class registerThread(Thread):
                                         "server_data[version]":PROTOCOL_VERSION,
                                         "server_data[num_users]":self.num_users,
                                         "act":"register"} )
-            
+
             try:
 
                 xml_dom = get_server_dom( data=data,path=self.path )  #  this POSTS the request and returns the result
@@ -696,7 +705,7 @@ class registerThread(Thread):
                     if META_DEBUG: print
                     if META_DEBUG: print "OOPS!  Is the Meta okay?  It should be returning an id, cookie, and interval."
                     if META_DEBUG: print "Check to see what it really returned.\n"
-                   
+
 
                 #  Let xml_dom get garbage collected
                 try:
