@@ -21,13 +21,13 @@
 # Author: Chris Davis
 # Maintainer:
 # Version:
-#   $Id: mplay_client.py,v 1.41 2003/10/10 05:02:16 snowdog_ Exp $
+#   $Id: mplay_client.py,v 1.49 2005/10/24 02:06:04 tdb30_ Exp $
 #
 # Description: This file contains the code for the client stubs of the multiplayer
 # features in the orpg project.
 #
 
-__version__ = "$Id: mplay_client.py,v 1.41 2003/10/10 05:02:16 snowdog_ Exp $"
+__version__ = "$Id: mplay_client.py,v 1.49 2005/10/24 02:06:04 tdb30_ Exp $"
 
 import orpg.minidom
 import socket
@@ -37,7 +37,7 @@ import traceback
 from threading import Event, Lock
 from xml.sax.saxutils import escape
 from struct import pack, unpack, calcsize
-
+from string import *
 from orpg.orpg_version import *
 
 
@@ -132,7 +132,8 @@ class client_base:
         self.ROLE_GM="GM"
         self.ROLE_PLAYER="PLAYER"
         self.ROLE_LURKER="LURKER"
-
+        self.lastmessagetime = time.time()
+        self.connecttime = time.time()
 
     def sendThread( self, arg ):
         "Sending thread.  This thread reads from the data queue and writes to the socket."
@@ -144,7 +145,7 @@ class client_base:
         while( self.get_status() == MPLAY_CONNECTED ):
             try:
                 readMsg = self.outbox.get( block=1 )
-                
+
             except Exception, text:
                 self.log_msg( ("outbox.get() got an exception:  ", text) )
 
@@ -163,7 +164,7 @@ class client_base:
 
         self.sendThreadExitEvent.set()
         self.log_msg( "sendThread has terminated..." )
-        
+
 
 
     def recvThread( self, arg ):
@@ -179,18 +180,18 @@ class client_base:
             bytes = len( readMsg )
             if bytes == 0:
                 break
-            
+
             # Check the length of the message
             bytes = len( readMsg )
 
             # Make sure we are still connected
             if bytes == 0:
                 break
-                    
+
             else:
                 # Pass along the message so it can be processed
                 self.inbox.put( readMsg )
-                        
+                self.update_idle_time() #update the last message time
         if bytes == 0:
             self.log_msg( "Remote has disconnected!" )
             self.set_status( MPLAY_DISCONNECTING )
@@ -222,7 +223,7 @@ class client_base:
 
         except socket.error, e:
             self.log_msg( e )
-                    
+
         except Exception, e:
             self.log_msg( e )
 
@@ -393,13 +394,64 @@ class client_base:
         # Return 1 if we are running as a server, else, return 0.
         # This method must be overloaded by whomever derives from us
         pass
-    
+
 
     def __str__(self):
         return "%s(%s)\nIP:%s\ngroup_id:%s\n" % (self.name, self.id, self.ip, self.group_id)
 
 
+    # idle time functions added by snowdog 3/31/04
+    def update_idle_time(self):
+        self.lastmessagetime = time.time()
 
+    def idle_time(self):
+        curtime = time.time()
+        idletime = curtime - self.lastmessagetime
+        return idletime
+
+    def idle_status(self):
+        idletime = self.idle_time()
+        idlemins = idletime / 60
+        status = "Unknown"
+        if idlemins < 3:
+            status = "Active"
+        elif idlemins < 10:
+            status = "Idle ("+str(int(idlemins))+" mins)"
+        else:
+            status = "Inactive ("+str(int(idlemins))+" mins)"
+        return status
+
+    def connected_time(self):
+        curtime = time.time()
+        timeoffset = curtime - self.connecttime
+        return timeoffset
+
+    def connected_time_string(self):
+        "returns the time client has been connected as a formated time string"
+        ct = self.connected_time()
+        d = int(ct/86400)
+        h = int( (ct-(86400*d))/3600 )
+        m = int( (ct-(86400*d)-(3600*h))/60)
+        s = int( (ct-(86400*d)-(3600*h)-(60*m)) )
+        cts =  zfill(d,2)+":"+zfill(h,2)+":"+zfill(m,2)+":"+zfill(s,2)
+        return cts
+
+
+
+
+
+
+
+
+
+
+#========================================================================
+#
+#
+#                           MPLAY CLIENT
+#
+#
+#========================================================================
 class mplay_client(client_base):
     "mplay client"
     def __init__(self,name,callbacks):
@@ -417,7 +469,7 @@ class mplay_client(client_base):
         # Should really find a better solution. -- SD 8/03
         self.orpgFrame_callback = callbacks['orpgFrame']
 
-        
+
         #self.version = VERSION
         #self.protocol_version = PROTOCOL_VERSION
         #self.client_string = CLIENT_STRING
@@ -431,7 +483,7 @@ class mplay_client(client_base):
     # implement from our base class
     def isServer( self ):
         return 0
-    
+
 
     def set_name(self,name):
         self.name =  name
@@ -499,7 +551,7 @@ class mplay_client(client_base):
     def get_my_info(self):
         return (self.name, self.ip, self.id, self.text_status, self.version, self.protocol_version, self.client_string, self.role)
 
-        
+
     def is_valid_id(self,id):
         self.statLock.acquire()
         value = self.players.has_key( id )
@@ -560,9 +612,40 @@ class mplay_client(client_base):
         self.update()
 
     def set_room_name(self,name,pwd=""):
+        loc = name.find("&")
+        oldloc=0
+        while loc > -1:
+            loc = name.find("&",oldloc)
+            if loc > -1:
+                b = name[:loc]
+                e = name[loc+1:]
+                name = b + "&amp;" + e
+                oldloc = loc+1
+
+        loc = name.find("'")
+        oldloc=0
+        while loc > -1:
+            loc = name.find("'",oldloc)
+            if loc > -1:
+                b = name[:loc]
+                e = name[loc+1:]
+                name = b + "&#39;" + e
+                oldloc = loc+1
+
+        loc = name.find('"')
+        oldloc=0
+        while loc > -1:
+            loc = name.find('"',oldloc)
+            if loc > -1:
+                b = name[:loc]
+                e = name[loc+1:]
+                name = b + "&#39;&#39;" + e
+                oldloc = loc+1
+
+
         self.outbox.put("<alter key=\"name\" val=\"" + name + "\" bpw=\"" + pwd + "\" plr=\"" + self.id +"\" gid=\"" + self.group_id + "\" />")
         self.update()
-        
+
 #---------------------------------------------------------
 # [END] Snowdog Password/Room Name altering code  12/02
 #---------------------------------------------------------
@@ -589,7 +672,7 @@ class mplay_client(client_base):
     def send_join_group(self,group_id,pwd):
         if (group_id != 0):
             self.update_role("LURKER")
-        self.outbox.put("<join_group from=\""+self.id+"\" pwd=\""+pwd+"\" group_id=\""+group_id+"\" />")
+        self.outbox.put("<join_group from=\""+self.id+"\" pwd=\""+pwd+"\" group_id=\""+str(group_id)+"\" />")
 
 
     def poll(self):
@@ -646,7 +729,7 @@ class mplay_client(client_base):
             latency = float( latency) / 10.0
             ping_msg = "Ping Results: "+str(latency)+" ms (parsed message, round trip)"
             self.on_receive(ping_msg,None)
-            
+
 
         elif tag_name == "group":
             #print head
@@ -730,7 +813,7 @@ class mplay_client(client_base):
             signal = xml_dom.getAttribute("signal")
             data = xml_dom.getAttribute("data")
             self.on_password_signal( signal,type,id,data )
-                
+
         if xml_dom:
             xml_dom.unlink()
 
@@ -841,9 +924,9 @@ class mplay_client(client_base):
     def start_disconnect(self):
         self.on_mplay_event(mplay_event(MPLAY_DISCONNECTING))
         self.outbox.put( self.toxml("del") )
-	  ## Client Side Disconect Forced -- Snowdog 10-09-2003
+          ## Client Side Disconect Forced -- Snowdog 10-09-2003
         #pause to allow GUI events time to sync.
-        time.sleep(1) 
+        time.sleep(1)
         self.do_disconnect()
 
 
