@@ -1,9 +1,13 @@
-VERSION = "1.6.1"
+VERSION = "1.6.3"
+SERVER_MIN_CLIENT_VERSION = "1.6.3"
+
+#BUILD NUMBER FORMAT: "YYMMDD-##" where ## is the incremental daily build index (if needed)
+BUILD = "051029-00"
 
 # This version is for network capability.
 PROTOCOL_VERSION = "1.2"
 
-CLIENT_STRING = "OpenRPG 1.6.1"
+CLIENT_STRING = "OpenRPG "+VERSION
 
 # These two are used in pyver.py to ensure a minimum python is available
 # If the minimum version you want doesn't have a micro (e.g. 2.0), use zero
