@@ -1,6 +1,6 @@
 # Copyright (C) 2000-2001 The OpenRPG Project
 #
-#	openrpg-dev@lists.sourceforge.net
+#        openrpg-dev@lists.sourceforge.net
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,18 +21,18 @@
 # Author: Chris Davis
 # Maintainer:
 # Version:
-#   $Id: orpg_windows.py,v 1.15 2003/02/03 20:26:09 posterboy Exp $
+#   $Id: orpg_windows.py,v 1.18 2005/10/20 02:20:08 mduo13 Exp $
 #
 # Description: orpg custom windows
 #
 
-__version__ = "$Id: orpg_windows.py,v 1.15 2003/02/03 20:26:09 posterboy Exp $"
+__version__ = "$Id: orpg_windows.py,v 1.18 2005/10/20 02:20:08 mduo13 Exp $"
 
 import os
 import systempath
 
 
-import orpg.dirpath 
+import orpg.dirpath
 #import minidom
 import orpg.orpg_xml
 import orpg.tools.rgbhex
@@ -62,10 +62,10 @@ class img_helper:
         try:
             data = urllib.urlretrieve(path)
             if data:
-                img = wxBitmap(data[0], img_type)                
+                img = wxBitmap(data[0], img_type)
             else:
                 raise IOError, "Image refused to load!"
-        except IOError, e:		       
+        except IOError, e:
             img = None
         return img
 
@@ -89,7 +89,7 @@ class img_helper:
         else:
             imf_type = None
         return img_type
-            
+
 
 
 ################################
@@ -103,7 +103,7 @@ class wxBoxedSizer(wxPanel):
         self.outline = wxStaticBox(self,-1,txt)
         self.ctrl = None
         EVT_SIZE(self, self.on_size)
-        
+
     def set_sizer(self,sizer):
         self.sizer = sizer
         self.SetSizer(self.sizer)
@@ -112,13 +112,21 @@ class wxBoxedSizer(wxPanel):
         self.ctrl = ctrl
 
     def on_size(self,event):
-        s = self.GetClientSizeTuple()   
+        s = self.GetClientSizeTuple()
         if self.sizer:
             self.sizer.SetDimension(20,20,s[0]-40,s[1]-40)
         if self.ctrl:
             self.ctrl.SetDimensions(20,20,s[0]-40,s[1]-40)
         self.outline.SetDimensions(5,5,s[0]-10,s[1]-10)
 
+    def SetMySize(self,size):
+        if hasattr(self, "SetMinSize"):
+            #wxPython >= 2.6
+            self.SetMinSize(size)
+        else:
+            #wxPython <= 2.4
+            self.SetSize(size)
+
 
 #####################
 ## A text editor for openrpg related text
@@ -198,18 +206,18 @@ class html_text_edit(wxPanel):
         self.text.SetInsertionPoint(beg)
         self.text.SetFocus()
         self.callback(wxEvent(self.text.GetId()))
-        
+
     def set_text(self,txt):
-        self.text.SetValue(txt)  
-    
+        self.text.SetValue(txt)
+
     def get_text(self):
         return self.text.GetValue()
-        
+
     def OnSize(self,event):
         (w,h) = self.GetClientSizeTuple()
         self.text.SetDimensions(0,0,w,h-25)
         self.sizer.SetDimension(0,h-25,w,25)
-       
+
 
 ################################
 ## controls
@@ -276,11 +284,11 @@ class orpgTextCtrl(wxTextCtrl):
         EVT_MENU(self, TEXT_HTML_IMG,self.on_menu)
         EVT_MENU(self, TEXT_HTML_URL,self.on_menu)
 
-        
+
     def on_rclick(self,evt):
         pt = evt.GetPosition()
         self.PopupMenu(self.edit_menu,pt)
-        
+
     def on_menu(self,evt):
         id = evt.GetId()
         if id == TEXT_COPY:
@@ -288,7 +296,7 @@ class orpgTextCtrl(wxTextCtrl):
         elif id == TEXT_CUT:
             self.Cut()
         elif id == TEXT_PASTE:
-            self.Paste()       
+            self.Paste()
         elif id == TEXT_SELECT_ALL:
             self.SetFocus()
             self.SetSelection(0,self.GetLastPosition())
@@ -320,7 +328,7 @@ class orpgTextCtrl(wxTextCtrl):
             self.Cut()
             self.WriteText("<hr>")
         elif id == TEXT_HTML_COLOR:
-            sel=self.GetStringSelection(); 
+            sel=self.GetStringSelection();
             self.Cut()
             data = wxColourData()
             data.SetChooseFull(true)
@@ -334,15 +342,15 @@ class orpgTextCtrl(wxTextCtrl):
         elif id == TEXT_HTML_BORDER:
             sel=self.GetStringSelection();
             self.Cut()
-            self.WriteText("<table border=1><tr><td>"+sel+"</td></tr></table>")            
+            self.WriteText("<table border=1><tr><td>"+sel+"</td></tr></table>")
         elif id == TEXT_DISPLAY_HTML:
             dlg=HTMLDialog(self,"HTML Preview",self.GetValue());
             dlg.Show()
             #dlg.Destroy()
             #about = MyAboutBox(self,obj.about())
-            
 
-            
+
+
 
 
 ################################
@@ -363,7 +371,7 @@ class HTMLDialog(wxDialog):
     def __init__(self, parent, title, text, bgcolor="#FFFFFF"):
         wxDialog.__init__(self, parent, -1, title,pos=(-1,-1),size=(400,400),style=wxRESIZE_BORDER|wxDEFAULT_DIALOG_STYLE)
         html = http_html_window(self,-1)
-        #html = wxHtmlWindow(self, -1, size=(600, 400))        
+        #html = wxHtmlWindow(self, -1, size=(600, 400))
         html.SetPage(self.page % (bgcolor, text))
         ir = html.GetInternalRepresentation()
         html.SetSize( (ir.GetWidth()+5, ir.GetHeight()+5) )
@@ -371,8 +379,8 @@ class HTMLDialog(wxDialog):
         self.SetSize(size=(600,400))
         self.CentreOnParent(wxBOTH)
     #def OnOK(self,event):
-        
-        
+
+
 class MyAboutBox(wxDialog):
     page = """
 <html>
@@ -388,17 +396,17 @@ class MyAboutBox(wxDialog):
 """
     def __init__(self, parent, text, bgcolor="#FFFFFF"):
         wxDialog.__init__(self, parent, -1, 'About',)
-        html = wxHtmlWindow(self, -1, size=(420, -1))        
+        html = wxHtmlWindow(self, -1, size=(420, -1))
         html.SetPage(self.page % (bgcolor, text))
         ir = html.GetInternalRepresentation()
         html.SetSize( (ir.GetWidth()+5, ir.GetHeight()+5) )
         self.SetClientSize(html.GetSize())
         self.CentreOnParent(wxBOTH)
-        
+
 ###########################
 ## HTML related clasees
 ###########################
-        
+
 class http_html_window(wxHtmlWindow):
     """ a wxHTMLwindow that will load links  """
     def __init__(self, parent, id):
@@ -408,15 +416,15 @@ class http_html_window(wxHtmlWindow):
         #self.title = title
 
     def OnLinkClicked(self, linkinfo):
-        address = linkinfo.GetHref()        
+        address = linkinfo.GetHref()
         if address[:4] == "http":
             self.load_url(address)
             self.local = 0
         elif address[0] == "#" or self.local:
             self.base_OnLinkClicked(linkinfo)
-        else:            
+        else:
             self.load_url(self.path+address)
-                
+
     def load_url(self,path):
         print path
         dlg = wxProgressDialog("HTML Document","Loading...",3,self)
@@ -437,7 +445,7 @@ class http_html_window(wxHtmlWindow):
     def load_file(self,path):
         self.LoadPage(path)
         self.local = 1
-  
+
 
 WEB_CLOSE = wxNewId()
 WEB_BACK = wxNewId()
@@ -456,8 +464,8 @@ class wxHTMLpanel(wxPanel):
         self.sizer.Add(wxButton(self, WEB_FORWARD, "Forward"), 1, wxEXPAND)
         self.sizer.Add(wxButton(self, WEB_SAVE, "Save"), 1, wxEXPAND)
         self.sizer.Add(wxButton(self, WEB_PRINT, "Print"), 1, wxEXPAND)
-        EVT_BUTTON(self, WEB_CLOSE, self.on_button) 
-        EVT_BUTTON(self, WEB_BACK, self.on_button) 
+        EVT_BUTTON(self, WEB_CLOSE, self.on_button)
+        EVT_BUTTON(self, WEB_BACK, self.on_button)
         EVT_BUTTON(self, WEB_FORWARD, self.on_button)
         EVT_BUTTON(self, WEB_PRINT, self.on_button)
         EVT_BUTTON(self, WEB_SAVE, self.on_button)
@@ -524,7 +532,7 @@ class wxPFrame(wxFrame):
         if wxPlatform == '__WXMSW__':
             icon = wxIcon(icon_file, wxBITMAP_TYPE_ICO)
             self.SetIcon(icon)
-        self.panel = None        
+        self.panel = None
         self.only_hide = only_hide
         self.parent = parent
         self.destroyed = 0
@@ -536,8 +544,8 @@ class wxPFrame(wxFrame):
         if self.only_hide:
             self.Show( false )
             self.Raise()
-        else:            
-            self.destroyed = 1            
+        else:
+            self.destroyed = 1
             self.Destroy()
         #print "window destroyed!"
 
@@ -546,7 +554,7 @@ class wxPFrame(wxFrame):
         (w,h) = self.GetClientSizeTuple()
         if self.panel:
             self.panel.SetDimensions(0,0,w,h)
-        
+
 
 
 class wxHTMLFrame(wxFrame):
@@ -564,16 +572,16 @@ class wxHTMLFrame(wxFrame):
 
     def load_file(self,path):
         self.html_wnd.load_file(path)
-        
-    def load_url(self,path):    
+
+    def load_url(self,path):
         self.html_wnd.load_url(path)
 
     def set_page(self,data):
         self.html_wnd.SetPage(data)
 
-    def load_img(self,path):    
+    def load_img(self,path):
         self.html_wnd.load_img(path)
-        
+
     def OnCloseMe(self, event):
         self.Close(true)
 
@@ -601,13 +609,13 @@ class wxMultiCheckBoxDlg(wxDialog):
         self.list = wxCheckListBox(self, sid, wxDefaultPosition, wxDefaultSize,opts)
         for s in selected:
             self.list.Check(s,1)
-                   
-        sizers['ctrls'].Add(wxStaticText(self, -1, text), 0, 0) 
-        sizers['ctrls'].Add(10,10)
+
+        sizers['ctrls'].Add(wxStaticText(self, -1, text), 0, 0)
+        sizers['ctrls'].Add(wxSize(10,10))
         sizers['ctrls'].Add(self.list, 1, wxEXPAND)
-        
-        sizers['buttons'].Add(wxButton(self, wxID_OK, "OK"), 1, wxEXPAND) 
-        sizers['buttons'].Add(10,10)
+
+        sizers['buttons'].Add(wxButton(self, wxID_OK, "OK"), 1, wxEXPAND)
+        sizers['buttons'].Add(wxSize(10,10))
         sizers['buttons'].Add(wxButton(self, wxID_CANCEL, "Cancel"), 1, wxEXPAND)
 
         width = 200
@@ -616,8 +624,8 @@ class wxMultiCheckBoxDlg(wxDialog):
         sizers['ctrls'].SetDimension(10,5,width-20,160)
         sizers['buttons'].SetDimension(10,170,width-20,25)
         EVT_BUTTON(self, wxID_OK, self.on_ok)
-        
-   
+
+
     def on_ok(self,evt):
         checked = []
         for i in range(len(self.opts)):
@@ -625,11 +633,11 @@ class wxMultiCheckBoxDlg(wxDialog):
                 checked.append(i)
         self.checked = checked
         self.EndModal(wxID_OK)
-        
+
     def get_selections(self):
         return self.checked
 
-    
+
 class wxMultiChoiceDlg(wxDialog):
     """ test """
     def __init__(self,parent,opts,text,caption,pos=wxDefaultPosition):
@@ -639,13 +647,13 @@ class wxMultiChoiceDlg(wxDialog):
 
         self.list = wxListBox(self, -1, wxDefaultPosition, wxDefaultSize,
                        opts, wxLB_EXTENDED)
-            
-        sizers['ctrls'].Add(wxStaticText(self, -1, text), 0, 0) 
-        sizers['ctrls'].Add(10,10)
+
+        sizers['ctrls'].Add(wxStaticText(self, -1, text), 0, 0)
+        sizers['ctrls'].Add(wxSize(10,10))
         sizers['ctrls'].Add(self.list, 1, wxEXPAND)
-        
-        sizers['buttons'].Add(wxButton(self, wxID_OK, "OK"), 1, wxEXPAND) 
-        sizers['buttons'].Add(10,10)
+
+        sizers['buttons'].Add(wxButton(self, wxID_OK, "OK"), 1, wxEXPAND)
+        sizers['buttons'].Add(wxSize(10,10))
         sizers['buttons'].Add(wxButton(self, wxID_CANCEL, "Cancel"), 1, wxEXPAND)
 
         width = 200
@@ -657,17 +665,17 @@ class wxMultiChoiceDlg(wxDialog):
 
     def on_ok(self,evt):
         self.EndModal(wxID_OK)
-        
-    def get_selections(self):
-        pass    
 
-        
+    def get_selections(self):
+        pass
+
+
 class wxMultiTextEntry(wxDialog):
     """ a dialog that takes two lists (labels and values) and creates a
         'label: value' style text edit control for each node in the dic"""
     def __init__(self,parent,tlist,vlist,caption,pos=wxDefaultPosition):
         wxDialog.__init__(self,parent,-1,caption,pos,wxDefaultSize)
-        
+
         num = len(tlist)
         sizers = { 'ctrls' : wxFlexGridSizer(num,2,5,0),
                     'buttons' : wxBoxSizer(wxHORIZONTAL) }
@@ -682,10 +690,10 @@ class wxMultiTextEntry(wxDialog):
             add_list.append((ctrls[i],1,wxEXPAND))
         self.ctrls = ctrls
         sizers['ctrls'].AddMany(add_list)
-        sizers['ctrls'].AddGrowableCol(1)        
-        
-        sizers['buttons'].Add(wxButton(self, wxID_OK, "OK"), 1, wxEXPAND) 
-        sizers['buttons'].Add(10,10)
+        sizers['ctrls'].AddGrowableCol(1)
+
+        sizers['buttons'].Add(wxButton(self, wxID_OK, "OK"), 1, wxEXPAND)
+        sizers['buttons'].Add(wxSize(10,10))
         sizers['buttons'].Add(wxButton(self, wxID_CANCEL, "Cancel"), 1, wxEXPAND)
 
         width = 300
@@ -701,7 +709,7 @@ class wxMultiTextEntry(wxDialog):
         for i in range(len(self.ctrls)):
             self.vlist[i] = self.ctrls[i].GetValue()
         self.EndModal(wxID_OK)
-        
+
     def get_values(self):
         return self.vlist
 
@@ -723,21 +731,21 @@ class wxScrolledMessageFrame(wxFrame):
         EVT_BUTTON(self, wxID_CANCEL, self.OnCloseMe)
         self.sizer.Add(self.ok, 1, wxEXPAND)
         self.sizer.Add(self.cancel, 1, wxEXPAND)
-        self.SetSizer(self.sizer)       
-        
+        self.SetSizer(self.sizer)
+
         self.onchange = callback
         EVT_SIZE(self, self.OnSize)
 
     def OnCloseMe(self, event):
         if wxID_OK == event.GetId():
-            txt = self.text.GetValue()                  
+            txt = self.text.GetValue()
             if(self.onchange):
                 self.onchange(txt)
         self.Close(true)
 
-    def OnCloseWindow(self, event):           
+    def OnCloseWindow(self, event):
         self.Destroy()
-        
+
     def OnSize(self,event):
         (w,h) = self.GetClientSizeTuple()
         self.text.SetDimensions(0,0,w,h-25)
@@ -787,7 +795,7 @@ class wxScrolledMessageFrameEditor(wxFrame):
         EVT_BUTTON(self, wxID_CANCEL, self.OnCloseMe)
         self.sizer.Add(self.cancel, 1, wxEXPAND)
 
-        self.SetSizer(self.sizer)       
+        self.SetSizer(self.sizer)
         EVT_SIZE(self, self.OnSize)
 
         # current position
@@ -798,7 +806,7 @@ class wxScrolledMessageFrameEditor(wxFrame):
     def OnDeHTML(self, event):
         text = re.sub( "\<[^<]*?\>", "", self.text.GetValue() )
         self.text.SetValue(text)
-        
+
     def OnMatchMe(self, event):
         # match case sensitive
         if self.matchCaseCheckBox.GetValue() == 1:
@@ -816,9 +824,9 @@ class wxScrolledMessageFrameEditor(wxFrame):
         self.matchPosition = string.find(textValue[self.matchPositionOld:], matchValue)
         # cumulate position for substring matching in continuing search
         self.matchPositionOld = self.matchPositionOld + self.matchPosition
-        
+
         # if match was found
-	if self.matchPosition >= 0:
+        if self.matchPosition >= 0:
             # highlight(select) match
             self.text.SetSelection(self.matchPositionOld, self.matchPositionOld + len(matchValue))
             # continue search from end of match
@@ -826,14 +834,14 @@ class wxScrolledMessageFrameEditor(wxFrame):
         # if match was not found, but match exists somewhere in buffer, start from top
         elif string.find(textValue, matchValue) >= 0:
             self.text.SetInsertionPoint(0)
-            self.OnMatchMe(self)            
-            
+            self.OnMatchMe(self)
+
     def OnCloseMe(self, event):
         self.Close(true)
 
-    def OnCloseWindow(self, event):           
+    def OnCloseWindow(self, event):
         self.Destroy()
-        
+
     def OnSize(self,event):
         (w,h) = self.GetClientSizeTuple()
         self.text.SetDimensions(0,0,w,h-25)
@@ -846,7 +854,7 @@ class scrolled_img_panel(wxPanel):
         wxPanel.__init__(self, parent, id)
         self.img_wnd = wxScrolledWindow(self, -1, style=wxHSCROLL | wxVSCROLL | wxSUNKEN_BORDER)
         self.img_wnd.SetBackgroundColour(wxWHITE)
-        EVT_SIZE(self, self.on_size)      
+        EVT_SIZE(self, self.on_size)
 
     def on_size(self,event):
         s = self.GetClientSizeTuple()
@@ -857,9 +865,9 @@ class scrolled_img_panel(wxPanel):
         ext = path[pos+1:]
         img_type = 0
         if ext == "gif":
-            img_type = wxBITMAP_TYPE_GIF 
+            img_type = wxBITMAP_TYPE_GIF
         elif ext == "jpg":
-            img_type = wxBITMAP_TYPE_JPEG  
+            img_type = wxBITMAP_TYPE_JPEG
         elif ext == "bmp":
             img_type = wxBITMAP_TYPE_BMP
 
@@ -875,8 +883,8 @@ class scrolled_img_panel(wxPanel):
             self.img_wnd.SetScrollbars(20, 20, bmp.GetWidth()/20,  bmp.GetHeight()/20)
             dlg.Update(3)
             dlg.Destroy()
-            
-    
+
+
 class wxScrolledImgFrame(wxFrame):
     def __init__(self, parent, caption, pos = None, size = None):
         if not pos:
@@ -885,19 +893,19 @@ class wxScrolledImgFrame(wxFrame):
             size = wxSize(300,300)
         wxFrame.__init__(self, parent, -1, caption, pos, size)
         self.img_wnd = wxScrolledWindow(self, -1)
-        self.ok = wxButton(self, wxID_OK, "OK")        
+        self.ok = wxButton(self, wxID_OK, "OK")
         EVT_BUTTON(self, wxID_OK, self.OnCloseMe)
         EVT_SIZE(self, self.OnSize)
-        
+
 
     def load_url(self,path):
         pos = string.rfind(path,'.')
         ext = path[pos+1:]
         img_type = 0
         if ext == "gif":
-            img_type = wxBITMAP_TYPE_GIF 
+            img_type = wxBITMAP_TYPE_GIF
         elif ext == "jpg":
-            img_type = wxBITMAP_TYPE_JPEG  
+            img_type = wxBITMAP_TYPE_JPEG
         elif ext == "bmp":
             img_type = wxBITMAP_TYPE_BMP
 
@@ -922,7 +930,7 @@ class wxScrolledImgFrame(wxFrame):
 
     def OnCloseWindow(self, event):
         self.Destroy()
-        
+
     def OnSize(self,event):
         (w,h) = self.GetClientSizeTuple()
         self.img_wnd.SetDimensions(0,0,w,h-25)
@@ -930,17 +938,17 @@ class wxScrolledImgFrame(wxFrame):
 
 
 class orpgProgressDlg(wxDialog):
-    def __init__(self, parent,  title="", text="", range=10 ):           
+    def __init__(self, parent,  title="", text="", range=10 ):
         wxDialog.__init__(self, parent, -1, title, size=wxSize(200,75))
         self.sizer = wxBoxSizer(wxVERTICAL)
         self.text = wxStaticText( self, -1, text)
-        self.gauge = wxGauge(self,-1,range)        
+        self.gauge = wxGauge(self,-1,range)
         self.sizer.Add(self.text,1,wxALIGN_CENTER | wxEXPAND)
         self.sizer.Add(self.gauge,1,wxALIGN_CENTER | wxEXPAND)
         (w,h) = self.GetClientSizeTuple()
         self.sizer.SetDimension(10,10,w-20,h-20)
-        
-    def Update(self,pos,text=None):        
+
+    def Update(self,pos,text=None):
         self.gauge.SetValue(pos)
         if text:
             self.text.SetLabel(text)
