@@ -22,12 +22,12 @@
 # Author: Chris Davis
 # Maintainer:
 # Version:
-#   $Id: player_list.py,v 1.7 2003/08/16 10:06:28 snowdog_ Exp $
+#   $Id: player_list.py,v 1.15 2005/10/24 02:06:04 tdb30_ Exp $
 #
 # Description: This is the main entry point of the oprg application
 #
 
-__version__ = "$Id: player_list.py,v 1.7 2003/08/16 10:06:28 snowdog_ Exp $"
+__version__ = "$Id: player_list.py,v 1.15 2005/10/24 02:06:04 tdb30_ Exp $"
 
 from orpg.orpg_windows import *
 import orpg.dirpath
@@ -44,8 +44,6 @@ global ROLE_LURKER; ROLE_LURKER = "LURKER"
 #########################
 PLAYER_BOOT = wxNewId()
 PLAYER_WHISPER = wxNewId()
-PLAYER_WHISPER_TOGGLE = wxNewId()
-PLAYER_WHISPER_GROUP = wxNewId()
 PLAYER_IGNORE = wxNewId()
 PLAYER_ROLE_MENU = wxNewId()
 PLAYER_ROLE_LURKER = wxNewId()
@@ -58,6 +56,20 @@ PLAYER_MODERATE_GIVE_VOICE = wxNewId()
 PLAYER_MODERATE_TAKE_VOICE = wxNewId()
 PLAYER_SHOW_VERSION = wxNewId()
 
+
+WG_LIST = {}
+
+#---------------------------------------------------------
+# [START] Digitalxero Multi Whisper Group 1/1/05
+#---------------------------------------------------------
+PLAYER_WG_MENU = wxNewId()
+PLAYER_WG_CREATE = wxNewId()
+PLAYER_WG_CLEAR_ALL = wxNewId()
+WG_MENU_LIST = {}
+#---------------------------------------------------------
+# [END] Digitalxero Multi Whisper Group 1/1/05
+#---------------------------------------------------------
+
 #---------------------------------------------------------
 # [START] Snowdog Password/Room Name altering code 12/02
 #---------------------------------------------------------
@@ -91,6 +103,20 @@ class player_list(wxListCtrl):
         self.InsertColumn( 0, "ID" )
         self.InsertColumn( 1, "Player" )
         self.InsertColumn( 2, "Status" )
+#---------------------------------------------------------
+# [START] Digitalxero Multi Whisper Group 1/1/05
+#---------------------------------------------------------
+        ##Main Menu
+        self.wgMenu = wxMenu()
+
+        #Add the Base Menu items, so they are always at the bottom
+        self.wgMenu.Append(PLAYER_WG_CREATE, "Create")
+        self.wgMenu.Append(PLAYER_WG_CLEAR_ALL, "Delete All Groups")
+
+
+#---------------------------------------------------------
+# [END] Digitalxero Multi Whisper Group 1/1/05
+#---------------------------------------------------------
 
         # Create the role menu
         self.roleMenu = wxMenu()
@@ -132,9 +158,13 @@ class player_list(wxListCtrl):
         self.menu.Append( PLAYER_IGNORE, "Toggle &Ignore" )
         self.menu.AppendSeparator()
         self.menu.Append( PLAYER_WHISPER, "Whisper" )
-        self.menu.Append( PLAYER_WHISPER_TOGGLE, "Toggle Whisper Group" )
-        self.menu.Append( PLAYER_WHISPER_GROUP, "Whisper To Group" )
-        self.menu.Enable( PLAYER_WHISPER_GROUP, false )
+#---------------------------------------------------------
+# [START] Digitalxero Multi Whisper Group 1/1/05
+#---------------------------------------------------------
+        self.menu.AppendMenu(PLAYER_WG_MENU, "Whisper Groups", self.wgMenu)
+#---------------------------------------------------------
+# [END] Digitalxero Multi Whisper Group 1/1/05
+#---------------------------------------------------------
         self.menu.AppendSeparator()
         self.menu.AppendMenu( PLAYER_MODERATE_MENU, "Moderate", self.moderateMenu )
         self.menu.AppendMenu( PLAYER_COMMAND_MENU, "Room Control", self.commandMenu )
@@ -147,8 +177,6 @@ class player_list(wxListCtrl):
         EVT_MENU( self, PLAYER_BOOT, self.on_menu_item )
         EVT_MENU( self, PLAYER_IGNORE, self.on_menu_item )
         EVT_MENU( self, PLAYER_WHISPER, self.on_menu_item )
-        EVT_MENU( self, PLAYER_WHISPER_TOGGLE, self.on_menu_item )
-        EVT_MENU( self, PLAYER_WHISPER_GROUP, self.on_menu_item )
         EVT_MENU( self, PLAYER_MODERATE_ROOM_ON, self.on_menu_moderate )
         EVT_MENU( self, PLAYER_MODERATE_ROOM_OFF, self.on_menu_moderate )
         EVT_MENU( self, PLAYER_MODERATE_GIVE_VOICE, self.on_menu_moderate )
@@ -158,6 +186,14 @@ class player_list(wxListCtrl):
         EVT_MENU( self, PLAYER_ROLE_GM, self.on_menu_role_change )
         EVT_MENU( self, PLAYER_SHOW_VERSION, self.on_menu_item )
 #---------------------------------------------------------
+# [START] Digitalxero Multi Whisper Group 1/1/05
+#---------------------------------------------------------
+        EVT_MENU( self, PLAYER_WG_CREATE, self.on_menu_whispergroup )
+        EVT_MENU( self, PLAYER_WG_CLEAR_ALL, self.on_menu_whispergroup )
+#---------------------------------------------------------
+# [END] Digitalxero Multi Whisper Group 1/1/05
+#---------------------------------------------------------
+#---------------------------------------------------------
 # [START] Snowdog Password/Room Name altering code 12/02
 #---------------------------------------------------------
         EVT_MENU( self, PLAYER_COMMAND_PASSWORD_ALTER, self.on_menu_password )
@@ -204,12 +240,97 @@ class player_list(wxListCtrl):
             if alter_name_dialog.ShowModal() == wxID_OK:
                 new_name = alter_name_dialog.GetValue()
                 chat.InfoPost( "Requesting room name change on server..." )
+
+                loc = new_name.find("&")
+                oldloc=0
+                while loc > -1:
+                    loc = new_name.find("&",oldloc)
+                    if loc > -1:
+                        b = new_name[:loc]
+                        e = new_name[loc+1:]
+                        new_name = b + "&amp;" + e
+                        oldloc = loc +1
+			
+                loc = new_name.find("'")
+                oldloc=0
+                while loc > -1:
+                    loc = new_name.find("'",oldloc)
+                    if loc > -1:
+                        b = new_name[:loc]
+                        e = new_name[loc+1:]
+                        new_name = b + "&#39;" + e
+                        oldloc = loc +1
+
+                loc = new_name.find('"')
+                oldloc=0
+                while loc > -1:
+                    loc = new_name.find('"',oldloc)
+                    if loc > -1:
+                        b = new_name[:loc]
+                        e = new_name[loc+1:]
+                        new_name = b + "&#39;&#39;" + e
+                        oldloc = loc +1
+
                 session.set_room_name(new_name, boot_pwd)
 
 #---------------------------------------------------------
 # [END] Snowdog Password/Room Name altering code 12/02
 #---------------------------------------------------------
 
+#---------------------------------------------------------
+# [START] Digitalxero Multi Whisper Group 1/1/05
+#---------------------------------------------------------
+
+    def clean_sub_menus(self):
+        for mid in WG_MENU_LIST:
+            try:
+                self.wgMenu.Remove(WG_MENU_LIST[mid]["menuid"])
+                WG_MENU_LIST[mid]["menu"].Destroy()
+            except:
+                self.wgMenu.UpdateUI()
+        if self.wgMenu.GetMenuItemCount() == 2:
+            WG_MENU_LIST.clear()
+        return
+
+    def on_menu_whispergroup( self, evt ):
+            "Add/Remove players from Whisper Groups"
+
+            id = evt.GetId()
+            item = self.GetItem( self.selected_item )
+            chat = self.myopenrpg.get_component("chat")
+
+            #See if it is the main menu
+            if id == PLAYER_WG_CREATE:
+                create_new_group_dialog = wxTextEntryDialog(self,"Enter Group Name","Create New Whisper Group")
+                if create_new_group_dialog.ShowModal() == wxID_OK:
+                    group_name = create_new_group_dialog.GetValue()
+                    WG_LIST[group_name] = {}
+                return
+            elif id == PLAYER_WG_CLEAR_ALL:
+                WG_LIST.clear()
+                return
+
+            #Check Sub Menus
+            for mid in WG_MENU_LIST:
+                if id == WG_MENU_LIST[mid]["add"]:
+                    WG_LIST[mid][int(item.GetText())] = int(item.GetText())
+                    return
+                elif id == WG_MENU_LIST[mid]["remove"]:
+                    del WG_LIST[mid][int(item.GetText())]
+                    return
+                elif id == WG_MENU_LIST[mid]["clear"]:
+                    WG_LIST[mid].clear()
+                    return
+                elif id == WG_MENU_LIST[mid]["whisper"]:
+                    chat.set_chat_text("/gw " + mid + "=")
+                    return
+
+            return
+
+#---------------------------------------------------------
+# [END] Digitalxero Multi Whisper Group 1/1/05
+#---------------------------------------------------------
+
 
 
     def on_menu_moderate( self, evt ):
@@ -232,15 +353,15 @@ class player_list(wxListCtrl):
         if id == PLAYER_MODERATE_ROOM_OFF:
             moderationString = (moderateRoomBase % "off")
             infoString = (infoRoomBase % "DISABLE")
-            
+
         elif id == PLAYER_MODERATE_GIVE_VOICE:
             moderationString = (moderatePlayerBase % (playerID, "on"))
             infoString = (infoPlayerBase % ("GIVE", chat.session.get_player_by_player_id( str(playerID) )[0], playerID))
-            
+
         elif id == PLAYER_MODERATE_TAKE_VOICE:
             moderationString = (moderatePlayerBase % (playerID, "off"))
             infoString = (infoPlayerBase % ("TAKE", chat.session.get_player_by_player_id( str(playerID) )[0], playerID))
-        
+
         # Now, send it to the server
         if moderationString:
             chat.chat_cmds.docmd( moderationString )
@@ -260,7 +381,7 @@ class player_list(wxListCtrl):
         roleString = None
         roleBase = "/role %d=%s"
         infoBase = "Attempting to assign the role of %s to (%d) %s..."
-        
+
         # Do type specific processing
         if id == PLAYER_ROLE_LURKER:
             roleName = ROLE_LURKER
@@ -297,7 +418,7 @@ class player_list(wxListCtrl):
         id = evt.GetId()
         session = self.myopenrpg.get_component("session")
         password_manager = self.myopenrpg.get_component("password_manager")
-        
+
         if id == PLAYER_BOOT:
             id = str(self.GetItemData(self.selected_item))
             boot_pwd = password_manager.GetPassword("admin",int(session.group_id))
@@ -309,43 +430,6 @@ class player_list(wxListCtrl):
             chat = self.myopenrpg.get_component("chat")
             chat.set_chat_text("/w " + id + "=")
 
-        elif id == PLAYER_WHISPER_TOGGLE:
-            # Fetch the current image index and toggle it back and forth
-            item = self.GetItem( self.selected_item )
-            if item.GetImage():
-                item.SetImage( 0 )
-                self.whisperCount -= 1
-            else:
-                item.SetImage( 1 )
-                self.whisperCount += 1
-
-            self.SetItem( item )
-
-            # Toggle the group whisper menu item
-            if self.whisperCount:
-                self.menu.Enable( PLAYER_WHISPER_GROUP, true )
-            else:
-                self.menu.Enable( PLAYER_WHISPER_GROUP, false )
-                
-        elif id == PLAYER_WHISPER_GROUP:
-            # Obtain the complete list of items, detect which ones have whisper turned on
-            ic = self.GetItemCount()
-            index = 0
-            idString = ""
-            first = 0
-            while index < ic:
-                item = self.GetItem( index )
-                if item.GetImage():
-                    if not first:
-                        idString += item.GetText()
-                        first = 1
-                    else:
-                        idString += "," + item.GetText()
-                index += 1
-
-            chat = self.myopenrpg.get_component("chat")
-            chat.set_chat_text("/w " + idString + "=")
-
         elif id == PLAYER_IGNORE:
             id = str(self.GetItemData(self.selected_item))
             chat = self.myopenrpg.get_component("chat")
@@ -378,7 +462,59 @@ class player_list(wxListCtrl):
             else:
                 self.menu.Enable(PLAYER_BOOT,1)
                 self.menu.SetLabel(PLAYER_BOOT,"Boot")
+#---------------------------------------------------------
+# [START] Digitalxero Multi Whisper Group 1/1/05
+#---------------------------------------------------------
+            item = self.GetItem( self.selected_item )
 
+            if len(WG_MENU_LIST) > len(WG_LIST):
+                self.clean_sub_menus()
+
+            if len(WG_LIST) == 0:
+                self.wgMenu.Enable(PLAYER_WG_CLEAR_ALL, false)
+            else:
+                self.wgMenu.Enable(PLAYER_WG_CLEAR_ALL, true)
+
+
+            for gid in WG_LIST:
+                if not WG_MENU_LIST.has_key(gid):
+                    WG_MENU_LIST[gid] = {}
+                    WG_MENU_LIST[gid]["menuid"] = wxNewId()
+                    WG_MENU_LIST[gid]["whisper"] = wxNewId()
+                    WG_MENU_LIST[gid]["add"] = wxNewId()
+                    WG_MENU_LIST[gid]["remove"] = wxNewId()
+                    WG_MENU_LIST[gid]["clear"] = wxNewId()
+                    WG_MENU_LIST[gid]["menu"] = wxMenu()
+
+                    WG_MENU_LIST[gid]["menu"].SetTitle(gid)
+                    WG_MENU_LIST[gid]["menu"].Append(WG_MENU_LIST[gid]["whisper"], "Whisper")
+                    WG_MENU_LIST[gid]["menu"].Append(WG_MENU_LIST[gid]["add"], "Add")
+                    WG_MENU_LIST[gid]["menu"].Append(WG_MENU_LIST[gid]["remove"], "Remove")
+                    WG_MENU_LIST[gid]["menu"].Append(WG_MENU_LIST[gid]["clear"], "Clear")
+                    self.wgMenu.PrependMenu(WG_MENU_LIST[gid]["menuid"], gid, WG_MENU_LIST[gid]["menu"])
+
+                if WG_LIST[gid].has_key(int(item.GetText())):
+                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["remove"], true)
+                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["add"], false)
+                else:
+                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["remove"], false)
+                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["add"], true)
+
+                if len(WG_LIST[gid]) == 0:
+                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["whisper"], false)
+                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["clear"], false)
+                else:
+                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["whisper"], true)
+                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["clear"], true)
+
+                #Event Stuff
+                EVT_MENU( self, WG_MENU_LIST[gid]["whisper"], self.on_menu_whispergroup )
+                EVT_MENU( self, WG_MENU_LIST[gid]["add"], self.on_menu_whispergroup )
+                EVT_MENU( self, WG_MENU_LIST[gid]["remove"], self.on_menu_whispergroup )
+                EVT_MENU( self, WG_MENU_LIST[gid]["clear"], self.on_menu_whispergroup )
+#---------------------------------------------------------
+# [END] Digitalxero Multi Whisper Group 1/1/05
+#---------------------------------------------------------
             self.PopupMenu(self.menu,pos)
 
 
@@ -402,6 +538,16 @@ class player_list(wxListCtrl):
         i = self.FindItemData(-1,int(player[2]))
         self.DeleteItem(i)
 
+#---------------------------------------------------------
+# [START] Digitalxero Multi Whisper Group 1/1/05
+#---------------------------------------------------------
+        for gid in WG_LIST:
+            if WG_LIST[gid].has_key(int(player[2])):
+                del WG_LIST[gid][int(player[2])]
+#---------------------------------------------------------
+# [END] Digitalxero Multi Whisper Group 1/1/05
+#---------------------------------------------------------
+
         # play sound
         setobj = self.myopenrpg.get_component('settings')
         sound_file = setobj.get_setting("DelSound")
@@ -418,7 +564,7 @@ class player_list(wxListCtrl):
             index += 1
         self.colorize_player_list()
         self.Refresh()
-    
+
     #  This method updates the player info
     #
     #  self:  reference to this PlayerList
@@ -461,7 +607,13 @@ class player_list(wxListCtrl):
 
     def reset(self):
         self.whisperCount = 0
-        self.menu.Enable( PLAYER_WHISPER_GROUP, false )
+#---------------------------------------------------------
+# [START] Digitalxero Multi Whisper Group 1/1/05
+#---------------------------------------------------------
+        WG_LIST.clear()
+#---------------------------------------------------------
+# [END] Digitalxero Multi Whisper Group 1/1/05
+#---------------------------------------------------------
         self.DeleteAllItems()
 
 
@@ -486,10 +638,11 @@ class player_list(wxListCtrl):
 
 
     def size_cols(self):
-        # moved skip here to see if it breaks       
-        w,h = self.GetClientSizeTuple()
-        w /= 8
-        self.SetColumnWidth( 0, w*2 )
-        self.SetColumnWidth( 1, w*3 )
-        self.SetColumnWidth( 2, w*3 )
-           
+##        # moved skip here to see if it breaks
+##        w,h = self.GetClientSizeTuple()
+##        w /= 8
+##        self.SetColumnWidth( 0, w*2 )
+##        self.SetColumnWidth( 1, w*2 )
+##        self.SetColumnWidth( 2, w*3 )
+        pass
+
