@@ -1,6 +1,6 @@
 # Copyright (C) 2000-2001 The OpenRPG Project
 #
-#	openrpg-dev@lists.sourceforge.net
+#   openrpg-dev@lists.sourceforge.net
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 # Author: Chris Davis
 # Maintainer:
 # Version:
-#   $Id: orpg_settings.py,v 1.22 2003/12/11 15:15:27 digitalxero Exp $
+#   $Id: orpg_settings.py,v 1.36 2005/11/17 04:24:48 mduo13 Exp $
 #
 # Description: classes for orpg settings
 #
@@ -29,8 +29,11 @@
 from orpg.orpg_windows import *
 import orpg.dirpath
 import config_files
+import config_update
 from orpg.orpg_xml import *
 from rgbhex import *
+import sys
+import os
 
 class settings_grid(wxGrid):
     """grid for gen info"""
@@ -87,16 +90,23 @@ class settings_grid(wxGrid):
         setting = self.GetCellValue(row,0)
         value = self.GetCellValue(row,1)
 
-	self.setting_data += [[setting, value]]
+        self.setting_data += [[setting, value]]
 
 
+    def get_h(self):
+        (w,h) = self.GetClientSizeTuple()
+        rows = self.GetNumberRows()
+        minh = (rows*17)+120
+        return minh
+
     def on_size(self,evt):
         (w,h) = self.GetClientSizeTuple()
         cols = self.GetNumberCols()
         col_w = w/(cols)
         for i in range(0,cols):
             self.SetColSize(i,col_w)
-        evt.Skip()
+        if wxPlatform == '__WXMSW__':
+             evt.Skip()
         self.Refresh()
 
 
@@ -108,7 +118,8 @@ class prefs_dialog(wxDialog):
     "Preferences dialog for OpenRPG"
     def __init__(self,parent,setobj,openrpg):
         SETTINGS_TABS = wxNewId()
-        wxDialog.__init__(self,parent,-1,"OpenRPG Preferences",wxDefaultPosition,wxSize(640,480))
+        wxDialog.__init__(self,parent,-1,"OpenRPG Preferences",wxDefaultPosition,size = wxSize(-1,-1), style = wxRESIZE_BORDER | wxSYSTEM_MENU | wxCAPTION)
+        self.chat = openrpg.get_component('chat')
         self.settings_tabs = wxNotebook(self, SETTINGS_TABS)
         self.settings_handlers = []
         chat = []
@@ -122,7 +133,7 @@ class prefs_dialog(wxDialog):
 
         settings = setobj.get_setting_keys()
         for m in range(len(settings)):
-	    if setobj.get_catagory(settings[m]) == "chat":
+            if setobj.get_catagory(settings[m]) == "chat":
                 chat.append(settings[m])
             elif setobj.get_catagory(settings[m]) == "general":
                 general.append(settings[m])
@@ -187,13 +198,18 @@ class prefs_dialog(wxDialog):
         self.settings_handlers.append(colors_tab)
         self.settings_tabs.AddPage(self.settings_handlers[7],"Chat Colors")
 
+        winsizer = wxBoxSizer(wxVERTICAL)
         sizer =  wxBoxSizer(wxHORIZONTAL)
+        tab_sizer = wxBoxSizer(wxHORIZONTAL)
+
+        tab_sizer.Add(self.settings_tabs, 1, wxEXPAND)
+
         sizer.Add(wxButton(self, wxID_OK, "OK"), 1, wxEXPAND)
-        sizer.Add(10,10)
+        sizer.Add(wxSize(10,10))
         sizer.Add(wxButton(self, wxID_CANCEL, "Cancel"), 1, wxEXPAND)
-        (w,h) = self.GetClientSizeTuple()
-        self.settings_tabs.SetDimensions(0,0,w,h-25)
-        sizer.SetDimension(0,h-25,w,25)
+
+        winsizer.Add(tab_sizer, 1, wxEXPAND | wxALIGN_TOP)
+        winsizer.Add(sizer, 0, wxEXPAND | wxALIGN_BOTTOM)
 
         self.general_tab =  general_tab
         self.chat_tab = chat_tab
@@ -204,29 +220,82 @@ class prefs_dialog(wxDialog):
         self.toolbar_tab = toolbar_tab
         self.colors_tab = colors_tab
         self.setobj = setobj
+        self.winsizer = winsizer
+
+        if wxPlatform == '__WXMSW__':
+            minh = self.general_tab.get_h()
+            if minh > 750:
+                minh = 750
+            self.SetSize((580,minh+10))
+            self.winsizer.SetDimension(0,0,580,minh-25)
+        else:
+            EVT_SIZE(self, self.on_size)
 
         EVT_BUTTON(self, wxID_OK, self.on_ok)
         EVT_NOTEBOOK_PAGE_CHANGED(self, SETTINGS_TABS, self.on_page_change)
-        EVT_SIZE(self, self.on_size)
+        #EVT_SIZE(self, self.on_size)
 
     def on_size(self,evt):
         (w,h) = self.GetClientSizeTuple()
-        self.settings_tabs.SetDimensions(0,0,w,h-25)
+        #self.settings_tabs.SetDimensions(0,0,w,h-25)
+        self.winsizer.SetDimension(0,0,w,h-25)
+
 
     def on_page_change(self,evt):
-        pass
+        p = self.settings_tabs.GetPage(evt.GetOldSelection())
+        p.SaveEditControlValue()
+        p.HideCellEditControl()
+        if wxPlatform == '__WXMSW__':
+            tmp = evt.GetSelection()
+            if tmp == 0:
+                minh = self.general_tab.get_h()
+            elif tmp == 1:
+                minh = self.chat_tab.get_h()
+            elif tmp == 2:
+                minh = self.map_tab.get_h()
+            elif tmp == 3:
+                minh = self.gametree_tab.get_h()
+            elif tmp == 4:
+                minh = self.macros_tab.get_h()
+            elif tmp == 5:
+                minh = self.roomlist_tab.get_h()
+            elif tmp == 6:
+                minh = self.toolbar_tab.get_h()
+            elif tmp == 7:
+                minh = self.colors_tab.get_h()
+
+            if minh > 750:
+                minh = 750
+
+            self.SetSize((580,minh+10))
+            self.winsizer.SetDimension(0,0,580,minh-25)
+        else:
+            pass
+
 
     def on_ok(self,evt):
+        #tablist = [self.settings_tabs.GetPage(t) for t in range(0,self.settings_tabs.GetPageCount())]
+        for t in range(0,self.settings_tabs.GetPageCount()):
+            self.settings_tabs.GetPage(t).SaveEditControlValue()
         for m in self.general_tab.setting_data:
             self.setobj.set_setting(m[0],m[1])
         for m in self.chat_tab.setting_data:
             self.setobj.set_setting(m[0],m[1])
             if m[0] == "tabbedwhispers":
                 self.warning_msg()
-            elif m[0] == "defaultfont":
-                self.warning_msg()
-            elif m[0] == "defaultfontsize":
-                self.warning_msg()
+            try:
+                if len(self.chat.parent.panel_list) > 0:
+                    for panel in self.chat.parent.panel_list:
+                        if m[0] == "defaultfont":
+                            panel.set_default_font(fontname=m[1])
+                        elif m[0] == "defaultfontsize":
+                            panel.set_default_font(fontsize=int(m[1]))
+                raise Exception()
+            except:
+                if m[0] == "defaultfont":
+                    self.chat.set_default_font(fontname=m[1])
+                elif m[0] == "defaultfontsize":
+                    self.chat.set_default_font(fontsize=int(m[1]))
         for m in self.map_tab.setting_data:
             self.setobj.set_setting(m[0],m[1])
         for m in self.gametree_tab.setting_data:
@@ -239,9 +308,31 @@ class prefs_dialog(wxDialog):
             self.setobj.set_setting(m[0],m[1])
         for m in self.toolbar_tab.setting_data:
             self.setobj.set_setting(m[0],m[1])
-        if len(self.toolbar_tab.setting_data) >0:
-            self.warning_msg()
-    	self.general_tab.DisableCellEditControl()
+
+            ##tabbed whispers are on
+            try:
+                if len(self.chat.parent.panel_list) > 0:
+                    for panel in self.chat.parent.panel_list:
+                        if m[0] == 'AliasTool_On':
+                            panel.toggle_alias(m[1])
+                        elif m[0] == 'ToGMsButton_On':
+                            panel.toggle_gm(m[1])
+                        elif m[0] == 'DiceButtons_On':
+                            panel.toggle_dice(m[1])
+                        elif m[0] == 'FormattingButtons_On':
+                                panel.toggle_formating(m[1])
+                raise Exception()
+            except:
+                if m[0] == 'AliasTool_On':
+                    self.chat.toggle_alias(m[1])
+                elif m[0] == 'ToGMsButton_On':
+                    self.chat.toggle_gm(m[1])
+                elif m[0] == 'DiceButtons_On':
+                    self.chat.toggle_dice(m[1])
+                elif m[0] == 'FormattingButtons_On':
+                    self.chat.toggle_formating(m[1])
+
+        self.general_tab.DisableCellEditControl()
         self.chat_tab.DisableCellEditControl()
         self.map_tab.DisableCellEditControl()
         self.gametree_tab.DisableCellEditControl()
@@ -273,42 +364,76 @@ class settings:
         #      when a key's value gets set.  See settings.set_change_handler()
         self.change_handler = {}
 
-        #  Load the two trees
+        #  Load the tree
         self.setup_ini(ini_xml)
 
+
+
+#===================================================
+# setup_ini()
+#
+# Reworked for version 1.6.3 release. --Snowdog (5/10/05)
+#   Revamped tree loading proceedure
+#   Added new user ini updater to auto-add missing keys
+#===================================================
+
     def setup_ini(self,ini_xml):
-        self.filename = orpg.dirpath.dir_struct["user"] + ini_xml     # This is the filename we're going to use
-        default_tree = self.loadTree(orpg.dirpath.dir_struct["template"]+"default_ini.xml")
-        config_files.validate_config_file(ini_xml,"default_ini.xml")
-        my_tree = self.loadTree(self.filename)
-        #  four cases possible
-        if (not default_tree):
-            if (not my_tree):   # Case 1:  not default_tree AND not my_tree:  complain and exit
-                msg = wxMessageDialog(None,"Restore " + ini_xml + " or default_ini.xml and start again.","Settings files bad or missing",wxOK)
+
+        default_filename = "default_ini.xml"  #default ini template name
+        self.filename = orpg.dirpath.dir_struct["user"] + ini_xml     # This is the filename we're going attempt to use
+        template =  orpg.dirpath.dir_struct["template"]+default_filename  #template fully qualified filename
+
+
+        result = config_files.validate_config_file(ini_xml,default_filename)  #ensures user ini file exists (by creating it if it doesn't)
+        if (result == 2): #file user_file was created. Print console warning.
+            print("Config file "+ini_xml+" was created from default template.")
+        if (result == 0):
+            msg = wxMessageDialog(None,"Restore " + ini_xml + " or default_ini.xml and start again.","Settings files bad or missing",wxOK)
+            msg.ShowModal()
+            msg.Destroy()
+            sys.exit()
+
+
+        my_tree = self.loadTree(self.filename) #get the DOM for the config file
+
+
+        if ( not my_tree ):
+            text = ini_xml + " structure invalid.\nUsing default config file instead.\nPlease remove or repair "+ini_xml+" file."
+            msg = wxMessageDialog(None,text,"Config File Error",wxOK)
+            msg.ShowModal()
+            msg.Destroy()
+            if (os.path.exists(template)):
+                my_tree = self.loadTree(template)
+                if (not my_tree):
+                    text = default_filename + " template invalid.\nPlease obtain a new copy of the template file. OpenRPG cannot load config information and will terminate."
+                    msg = wxMessageDialog(None,text,"Unrecoverable Error",wxOK)
+                    msg.ShowModal()
+                    msg.Destroy()
+                    sys.exit()
+                #savedAs = self.saveTreeSafely(ini_xml, my_tree)
+                #move the old ini.xml file out of the way. This has to be done with file I/O cause the tree is not viable
+                savedAs = self.saveTreeSafely(ini_xml, my_tree)
+                text = "Your "+ini_xml+" config file has been automatically repaired.\nYour original version has been saved as "+savedAs+" if needed."
+                msg = wxMessageDialog(None,text,"Config File Updated",wxOK)
                 msg.ShowModal()
                 msg.Destroy()
-                sys.exit()
-            else:               # Case 2:  not default_tree AND my_tree:  Just use my_tree as-is
-                self.xml_dom = my_tree
-        else:
-            if (not my_tree):   # Case 3:  default_tree AND not my_tree:  Just use default_tree as-is
-                self.xml_dom = default_tree
-            else:               # Case 4:  Add nodes from default_tree that aren't in my_tree to my_tree
-                for key in self.get_tree_setting_keys(default_tree,hidden = 1):  #  Cycle through all default keys
-                    setting = self.get_tree_value(my_tree,key)                 #  See what my_tree has
-                    if not setting:                                              #  If nothing,
-                        self.set_tree_value(my_tree,key,self.get_tree_value(default_tree,key))   # Use defaults
-                    catagory = self.get_tree_value(my_tree,key,attrib="catagory")
-                    if not catagory:
-                        self.set_tree_value(my_tree,key,self.get_tree_value(default_tree,key,attrib="catagory"),attrib="catagory")
-                    help = self.get_tree_value(my_tree,key,attrib="help")
-                    if not help:
-                        self.set_tree_value(my_tree,key,self.get_tree_value(default_tree,key,attrib="help"),attrib="help")
-                    options = self.get_tree_value(my_tree,key,attrib="options")
-                    if not options:
-                        self.set_tree_value(my_tree,key,self.get_tree_value(default_tree,key,attrib="options"),attrib="options")
-                self.xml_dom = my_tree               #  Now that my_tree is fixed up, use it
-                default_tree.unlink()  # free up circular refs in unused tree
+
+        if (result == 1): #file was loaded from the user file...
+            if (config_update.UpdateIniFile(my_tree, template)): #verify all keys against the template ini file and update/add if required.
+                #user ini has been updated. Save to disk.
+                savedAs = self.saveTreeSafely(ini_xml, my_tree)
+                text = "Your "+ini_xml+" config file has been automatically updated.\nYour original version has been saved as "+savedAs+" if needed."
+                msg = wxMessageDialog(None,text,"Config File Updated",wxOK)
+                msg.ShowModal()
+                msg.Destroy()
+
+
+        #At this point my_tree should contain valid and template updated config data
+
+        self.xml_dom = my_tree
+
+
+
 
     def reload_settings(self,chat):
         try:
@@ -464,3 +589,31 @@ class settings:
     def save(self):
         self.saveTree(self.xml_dom)
 
+
+    #==========================================================
+    # saveTreeSafely()
+    #
+    # Moves a copy of the original ini file out of the way
+    # then saves the (updated) ini data to the original location
+    # automatic filename postfix prevents file overwrite
+    # 5/10/05                                        --Snowdog
+    #==========================================================
+    def saveTreeSafely(self, baseFilename, tree):
+
+        #write file to disk making sure not to overwrite an existing file.
+        index = 1
+        file = baseFilename+"-"+str(index)
+        while ( os.path.exists(orpg.dirpath.dir_struct["user"]+file)):
+            index = index +1
+            file = baseFilename+"-"+str(index)
+        #move the original ini out of the way
+        os.rename(orpg.dirpath.dir_struct["user"]+baseFilename, orpg.dirpath.dir_struct["user"]+file)
+
+
+        #write the updated file
+        ini = open(orpg.dirpath.dir_struct["user"] + baseFilename,"w")
+        ini.write(toxml(tree,1))
+        ini.close()
+        return file
+
+
