@@ -11,10 +11,10 @@
     version 1.0 as the final version.
 
     Still needed:
-     more support for WinCE
-     support for MS-DOS (PythonDX ?)
-     support for Amiga and other still unsupported platforms running Python
-     support for additional Linux distributions
+    - more support for WinCE
+    - support for MS-DOS (PythonDX ?)
+    - support for Amiga and other still unsupported platforms running Python
+    - support for additional Linux distributions
 
     Many thanks to all those who helped adding platform specific
     checks (in no particular order):
